{*
 *******************************************************************************
 *
 *  Copyright 2024 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 *}
{*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 *}

unit riegl.rdb.default.metadata;

{$WRITEABLECONST ON} // see section "initialization"

interface

// Meta data items definition version
const
  RDB_META_DATA_ITEMS_VERSION = '1.1.54';
  RDB_META_DATA_ITEMS_DATE = '2023-01-19';

// Meta data item states
const
  RDB_STATUS_REQUIRED = 1; // mandatory item
  RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
type
  TRDBPointcloudMetaDataItemInfo = record
    Name        : System.String;
    Title       : System.String;
    Description : System.String;
    Status      : System.Byte;
    Schema      : System.String;
    Example     : System.String;
  end;
  PRDBPointcloudMetaDataItemInfo = ^TRDBPointcloudMetaDataItemInfo;

// Angular notch filter parameters for window glass echoes
const
  RDB_RIEGL_ANGULAR_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.angular_notch_filter';
    Title       : 'Angular Notch Filter';
    Description : 'Angular notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"angle":{"description":"Angle [deg]","items":{"type":"n'
      + 'umber"},"type":"array"},"amplitude_mean":{"description":"Mean '
      + 'amplitude [dB]","items":{"type":"number"},"type":"array"},"range_mean"'
      + ':{"description":"Mean range '
      + '[m]","items":{"type":"number"},"type":"array"}},"title":"Angular Notch'
      + ' Filter","description":"Angular notch filter parameters for window '
      + 'glass echoes","required":["angle","range_mean","amplitude_mean"],"type'
      + '":"object","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"angle":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0],"amp'
      + 'litude_mean":[3.780913,3.780913,3.480913,3.120913,2.850913,2.720913,2.'
      + '680913,2.610913,2.530913,2.570913,2.570913],"range_mean":[0.094,0.094,'
      + '0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,0.0675,0.06475]}'
    );
  );

// Atmospheric parameters
const
  RDB_RIEGL_ATMOSPHERE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.atmosphere';
    Title       : 'Atmosphere';
    Description : 'Atmospheric parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"pressure":{"description":"Pressure along measurment '
      + 'path '
      + '[mbar]","type":"number"},"temperature":{"description":"Temperature '
      + 'along measurement path '
      + '[\u00b0C]","type":"number"},"attenuation":{"description":"Atmospheric '
      + 'attenuation [1/km]","type":"number"},"amsl":{"description":"Height '
      + 'above mean sea level (AMSL) '
      + '[m]","type":"number"},"pressure_sl":{"description":"Atmospheric '
      + 'pressure at sea level '
      + '[mbar]","type":"number"},"wavelength":{"description":"Laser wavelength'
      + ' [nm]","type":"number"},"rel_humidity":{"description":"Relative '
      + 'humidity along measurement path '
      + '[%]","type":"number"},"group_velocity":{"description":"Group velocity '
      + 'of laser beam [m/s]","type":"number"}},"title":"Atmospheric '
      + 'Parameters","description":"Atmospheric parameters","required":["temper'
      + 'ature","pressure","rel_humidity","pressure_sl","amsl","group_velocity"'
      + ',"attenuation","wavelength"],"type":"object","$schema":"http://json-sc'
      + 'hema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"pressure":970,"temperature":7,"attenuation":0.028125,"amsl":0,"press'
      + 'ure_sl":970,"wavelength":1550,"rel_humidity":63,"group_velocity":29971'
      + '1000.0}'
    );
  );

// Laser beam geometry details
const
  RDB_RIEGL_BEAM_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.beam_geometry';
    Title       : 'Beam Geometry';
    Description : 'Laser beam geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"beam_divergence":{"minimum":0,"exclusiveMinimum":false'
      + ',"description":"Beam divergence in far field [rad]","type":"number"},"'
      + 'beam_exit_diameter":{"minimum":0,"exclusiveMinimum":false,"description'
      + '":"Beam width at exit aperture [m]","type":"number"}},"title":"Beam '
      + 'Geometry","description":"Laser beam geometry details","required":["bea'
      + 'm_exit_diameter","beam_divergence"],"type":"object","$schema":"http://'
      + 'json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"beam_divergence":0.0003,"beam_exit_diameter":0.0072}'
    );
  );

// List of control object type definitions
const
  RDB_RIEGL_CONTROL_OBJECT_CATALOG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_catalog';
    Title       : 'Control Object Catalog';
    Description : 'List of control object type definitions';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"types":{"uniqueItems":true,"items":{"oneOf":[{"$ref":"'
      + '#/definitions/rectangle"},{"$ref":"#/definitions/checkerboard2x2"},{"$'
      + 'ref":"#/definitions/chevron"},{"$ref":"#/definitions/circular_disk"},{'
      + '"$ref":"#/definitions/cylinder"},{"$ref":"#/definitions/sphere"},{"$re'
      + 'f":"#/definitions/round_corner_cube_prism"}],"type":"object"},"type":"'
      + 'array"}},"title":"Control Object Catalog","description":"List of '
      + 'control object type definitions","required":["types"],"type":"object",'
      + '"definitions":{"checkerboard2x2":{"description":"checkerboard 2 by 2",'
      + '"type":"object","allOf":[{"$ref":"#/definitions/common"},{"properties"'
      + ':{"square_length":{"minimum":0,"exclusiveMinimum":true,"description":"'
      + 'length of a square of the checkerboard in meters","type":"number"},"sh'
      + 'ape":{"enum":["checkerboard2x2"],"description":"shape '
      + 'identifier","type":"string"}},"description":"checkerboard specific pro'
      + 'perties","required":["shape","square_length"],"type":"object"}]},"comm'
      + 'on":{"properties":{"name":{"minLength":3,"description":"unique type id'
      + 'entifier","type":"string"},"surface_type":{"enum":["retro_reflective_f'
      + 'oil","diffuse"],"description":"surface material '
      + 'type","type":"string"},"description":{"description":"string describing'
      + ' the object","type":"string"},"shape":{"enum":["rectangle","checkerboa'
      + 'rd2x2","chevron","circular_disk","cylinder","sphere","round_corner_cub'
      + 'e_prism"],"description":"shape '
      + 'identifier","type":"string"}},"description":"common object properties"'
      + ',"required":["name","shape"],"type":"object"},"sphere":{"description":'
      + '"sphere","type":"object","allOf":[{"$ref":"#/definitions/common"},{"pr'
      + 'operties":{"diameter":{"minimum":0,"exclusiveMinimum":true,"descriptio'
      + 'n":"diameter in meters","type":"number"},"shape":{"enum":["sphere"],"d'
      + 'escription":"shape identifier","type":"string"}},"description":"sphere'
      + ' specific properties","required":["shape","diameter"],"type":"object"}'
      + ']},"circular_disk":{"description":"circular disk","type":"object","all'
      + 'Of":[{"$ref":"#/definitions/common"},{"properties":{"diameter":{"minim'
      + 'um":0,"exclusiveMinimum":true,"description":"diameter in '
      + 'meters","type":"number"},"offset":{"description":"offset in meters, '
      + 'e.g. reflector constant (optional)","type":"number"},"shape":{"enum":['
      + '"circular_disk"],"description":"shape '
      + 'identifier","type":"string"}},"description":"circular disk specific pr'
      + 'operties","required":["shape","diameter"],"type":"object"}]},"chevron"'
      + ':{"description":"chevron","type":"object","allOf":[{"$ref":"#/definiti'
      + 'ons/common"},{"properties":{"thickness":{"minimum":0,"exclusiveMinimum'
      + '":true,"description":"thickness in meters","type":"number"},"outside_e'
      + 'dge_length":{"minimum":0,"exclusiveMinimum":true,"description":"length'
      + ' of the two outer edges in meters","type":"number"},"shape":{"enum":["'
      + 'chevron"],"description":"shape '
      + 'identifier","type":"string"}},"description":"chevron specific properti'
      + 'es","required":["shape","outside_edge_length","thickness"],"type":"obj'
      + 'ect"}]},"rectangle":{"description":"rectangle","type":"object","allOf"'
      + ':[{"$ref":"#/definitions/common"},{"properties":{"length":{"minimum":0'
      + ',"exclusiveMinimum":true,"description":"length in meters","type":"numb'
      + 'er"},"width":{"minimum":0,"exclusiveMinimum":true,"description":"width'
      + ' in meters","type":"number"},"shape":{"enum":["rectangle"],"type":"str'
      + 'ing"}},"description":"rectangle specific properties","required":["shap'
      + 'e","length","width"],"type":"object"}]},"cylinder":{"description":"cyl'
      + 'inder","type":"object","allOf":[{"$ref":"#/definitions/common"},{"prop'
      + 'erties":{"diameter":{"minimum":0,"exclusiveMinimum":true,"description"'
      + ':"diameter in meters","type":"number"},"height":{"minimum":0,"exclusiv'
      + 'eMinimum":true,"description":"height in meters","type":"number"},"shap'
      + 'e":{"enum":["cylinder"],"description":"shape '
      + 'identifier","type":"string"}},"description":"cylinder specific propert'
      + 'ies","required":["shape","diameter","height"],"type":"object"}]},"roun'
      + 'd_corner_cube_prism":{"description":"round corner cube prism","type":"'
      + 'object","allOf":[{"$ref":"#/definitions/common"},{"properties":{"diame'
      + 'ter":{"minimum":0,"exclusiveMinimum":true,"description":"diameter in '
      + 'meters","type":"number"},"offset":{"description":"offset in meters, '
      + 'e.g. reflector constant (optional)","type":"number"},"shape":{"enum":['
      + '"round_corner_cube_prism"],"description":"shape '
      + 'identifier","type":"string"}},"description":"round corner cube prism '
      + 'specific properties","required":["shape","diameter"],"type":"object"}]'
      + '}},"$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"types":[{"length":0.6,"name":"Rectangle '
      + '60x30","description":"Rectangle (60cm x 30cm)","width":0.3,"shape":"re'
      + 'ctangle"},{"length":0.8,"name":"Rectangle '
      + '80x40","description":"Rectangle (80cm x '
      + '40cm)","width":0.4,"shape":"rectangle"},{"name":"Checkerboard2x2 '
      + '30","description":"Checkerboard (square length: 30cm)","square_length"'
      + ':0.3,"shape":"checkerboard2x2"},{"name":"Checkerboard2x2 '
      + '50","description":"Checkerboard (square length: 50cm)","square_length"'
      + ':0.5,"shape":"checkerboard2x2"},{"outside_edge_length":0.6096,"name":"'
      + 'Chevron 24''''/4''''","description":"Chevron (a=24''''; b=4'''')","thickness":'
      + '0.1016,"shape":"chevron"},{"diameter":0.5,"name":"Circular Disk '
      + '50","surface_type":"diffuse","description":" Circular Disk (diameter: '
      + '50cm)","shape":"circular_disk"},{"diameter":0.05,"name":"RIEGL flat '
      + 'reflector 50 mm","description":"flat circular reflector from '
      + 'retro-reflective foil","surface_type":"retro_reflective_foil","offset"'
      + ':0.0,"shape":"circular_disk"},{"diameter":0.1,"name":"RIEGL flat '
      + 'reflector 100 mm","description":"flat circular reflector from '
      + 'retro-reflective foil","surface_type":"retro_reflective_foil","offset"'
      + ':0.0,"shape":"circular_disk"},{"diameter":0.15,"name":"RIEGL flat '
      + 'reflector 150 mm","description":"flat circular reflector from '
      + 'retro-reflective foil","surface_type":"retro_reflective_foil","offset"'
      + ':0.0,"shape":"circular_disk"},{"diameter":0.05,"name":"RIEGL '
      + 'cylindrical reflector 50 mm","description":"cylindrical reflector from'
      + ' retro-reflective foil","surface_type":"retro_reflective_foil","height'
      + '":0.05,"shape":"cylinder"},{"diameter":0.1,"name":"RIEGL cylindrical '
      + 'reflector 100 mm","description":"cylindrical reflector from '
      + 'retro-reflective foil","surface_type":"retro_reflective_foil","height"'
      + ':0.1,"shape":"cylinder"},{"diameter":0.2,"name":"Sphere 200 '
      + 'mm","description":"Sphere (diameter: 200 '
      + 'mm)","shape":"sphere"},{"diameter":0.05,"name":"Corner Cube Prism 50 '
      + 'mm","description":"round corner cube prism","offset":0.0,"shape":"roun'
      + 'd_corner_cube_prism"}],"comments":["This file contains a list of '
      + 'control object types (aka. ''catalog'').","Each type is described by an '
      + 'object,","which must contain at least the following parameters:","  - '
      + 'name: unique identifier of the type","  - shape: one of the following '
      + 'supported shapes:","      - rectangle","      - checkerboard2x2","'
      + '      - chevron","      - circular_disk","      - cylinder","      - '
      + 'sphere","      - round_corner_cube_prism","Depending on ''shape'', the '
      + 'following parameters must/may be specified:","  - rectangle:","      -'
      + ' length: length in meters","      - width: width in meters","  - '
      + 'checkerboard2x2:","      - square_length: length of a square of the '
      + 'checkerboard in meters","  - circular_disk:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","  - chevron:","      - outside_edge_length: '
      + 'length of the two outer edges in meters","      - thickness: thickness'
      + ' in meters","  - cylinder:","      - diameter: diameter in meters","'
      + '      - height: height in meters","  - sphere:","      - diameter: '
      + 'diameter in meters","  - round_corner_cube_prism:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","Optional parameters:","    - description: string'
      + ' describing the object","    - surface_type: surface material type '
      + '(either ''retro_reflective_foil'' or ''diffuse'')"]}'
    );
  );

// Details about the control object reference file
const
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_reference_file';
    Title       : 'Control Object Reference file';
    Description : 'Details about the control object reference file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"re'
      + 'ference_file":{"properties":{"file_uuid":{"description":"Control '
      + 'object file''s Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"file_path":{"description":"Path of the '
      + 'control object file relative to referring '
      + 'file","type":"string"}},"description":"Reference to a control object f'
      + 'ile","required":["file_uuid","file_path"],"type":"object"}},"title":"C'
      + 'ontrol Object Reference file","description":"Details about the control'
      + ' object reference file","type":"object"}'
    );

    Example : (''
      + '{"reference_file":{"file_uuid":"810f5d57-eccf-49ed-b07a-0cdd109b4213",'
      + '"file_path":"../../../10_CONTROL_OBJECTS/ControlPoints.cpx"}}'
    );
  );

// Detection probability as a function of amplitude
const
  RDB_RIEGL_DETECTION_PROBABILITY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.detection_probability';
    Title       : 'Detection Probability';
    Description : 'Detection probability as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"detection_probability":{"description":"Detection '
      + 'probability [0..1]","items":{"type":"number"},"type":"array"},"amplitu'
      + 'de":{"description":"Amplitude '
      + '[dB]","items":{"type":"number"},"type":"array"}},"title":"Detection '
      + 'Probability","description":"Detection probability as a function of amp'
      + 'litude","required":["amplitude","detection_probability"],"type":"objec'
      + 't","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"detection_probability":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]'
      + ',"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0]}'
    );
  );

// Details about the device used to acquire the point cloud
const
  RDB_RIEGL_DEVICE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device';
    Title       : 'Device Information';
    Description : 'Details about the device used to acquire the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"serial_number":{"description":"Device serial number '
      + '(e.g. '
      + 'S2221234)","type":"string"},"channel_text":{"description":"Optional '
      + 'channel description (e.g. ''Green Channel'' for multi-channel '
      + 'devices)","type":"string"},"device_build":{"description":"Device build'
      + ' variant","type":"string"},"device_type":{"description":"Device type '
      + 'identifier (e.g. VZ-400i)","type":"string"},"channel_number":{"minimum'
      + '":0,"exclusiveMinimum":false,"description":"Laser channel number (not '
      + 'defined or 0: single channel '
      + 'device)","type":"integer"},"device_name":{"description":"Optional '
      + 'device name (e.g. ''Scanner 1'' for multi-scanner '
      + 'systems)","type":"string"}},"title":"Device '
      + 'Information","description":"Details about the device used to acquire '
      + 'the point cloud","required":["device_type","serial_number"],"type":"ob'
      + 'ject","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"serial_number":"S2221234","channel_text":"","device_build":"","devic'
      + 'e_type":"VZ-400i","channel_number":0,"device_name":"Scanner 1"}'
    );
  );

// Scanner device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry';
    Title       : 'Device Geometry';
    Description : 'Scanner device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"secondary":{"properties":{"ID":{"maxItems":2,"minItems'
      + '":2,"description":"Structure identifier","items":{"type":"integer"},"t'
      + 'ype":"array"},"content":{"description":"Internal calibration values","'
      + 'items":{"type":"number"},"type":"array"}},"description":"Additional '
      + 'device geometry structure (optional)","required":["ID","content"],"typ'
      + 'e":"object"},"primary":{"properties":{"ID":{"maxItems":2,"minItems":2,'
      + '"description":"Structure identifier","items":{"type":"integer"},"type"'
      + ':"array"},"content":{"description":"Internal calibration values","item'
      + 's":{"type":"number"},"type":"array"}},"description":"Primary device '
      + 'geometry structure (mandatory)","required":["ID","content"],"type":"ob'
      + 'ject"},"amu":{"properties":{"lineCC":{"minimum":0,"exclusiveMinimum":f'
      + 'alse,"description":"Line Circle Count (number of LSBs per full '
      + 'rotation about line axis)","type":"number"},"frameCC":{"minimum":0,"ex'
      + 'clusiveMinimum":false,"description":"Frame Circle Count (number of '
      + 'LSBs per full rotation about frame '
      + 'axis)","type":"number"}},"description":"Angle Measurement '
      + 'Unit","type":"object"}},"title":"Device '
      + 'Geometry","description":"Scanner device geometry details","required":['
      + '"primary"],"type":"object","$schema":"http://json-schema.org/draft-04/'
      + 'schema#"}'
    );

    Example : (''
      + '{"secondary":{"ID":[91,0],"content":[0]},"primary":{"ID":[4,0],"conten'
      + 't":[0]},"amu":{"lineCC":124000,"frameCC":124000}}'
    );
  );

// Scanner passive channel device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry_passive_channel';
    Title       : 'Device Geometry Passive Channel';
    Description : 'Scanner passive channel device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"primary":{"properties":{"ID":{"maxItems":2,"minItems":'
      + '2,"description":"Structure identifier","items":{"type":"integer"},"typ'
      + 'e":"array"},"content":{"description":"Internal calibration values","it'
      + 'ems":{"type":"number"},"type":"array"}},"description":"Primary device '
      + 'geometry structure (mandatory)","required":["ID","content"],"type":"ob'
      + 'ject"}},"title":"Device Geometry Passive '
      + 'Channel","description":"Scanner passive channel device geometry detail'
      + 's","required":["primary"],"type":"object","$schema":"http://json-schem'
      + 'a.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"primary":{"ID":[143,0],"content":[0]}}'
    );
  );

// Limits of the measured values output by the device
const
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_output_limits';
    Title       : 'Device Output Limits';
    Description : 'Limits of the measured values output by the device';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"am'
      + 'plitude_minimum":{"description":"Minimum possible amplitude in '
      + 'dB.","type":"number"},"deviation_minimum":{"description":"Minimum '
      + 'possible pulse shape '
      + 'deviation.","type":"number"},"range_maximum":{"description":"Maximum '
      + 'possible range in meters.","type":"number"},"mta_zone_count_maximum":{'
      + '"description":"Maximum number of MTA '
      + 'zones.","type":"number"},"range_minimum":{"description":"Minimum '
      + 'possible range in '
      + 'meters.","type":"number"},"echo_count_maximum":{"description":"Maximum'
      + ' number of echoes a laser shot can '
      + 'have.","type":"number"},"amplitude_maximum":{"description":"Maximum '
      + 'possible amplitude in dB.","type":"number"},"background_radiation_maxi'
      + 'mum":{"description":"Maximum possible background radiation.","type":"n'
      + 'umber"},"reflectance_maximum":{"description":"Maximum possible '
      + 'reflectance in '
      + 'dB.","type":"number"},"deviation_maximum":{"description":"Maximum '
      + 'possible pulse shape deviation.","type":"number"},"reflectance_minimum'
      + '":{"description":"Minimum possible reflectance in dB.","type":"number"'
      + '},"background_radiation_minimum":{"description":"Minimum possible '
      + 'background radiation.","type":"number"}},"title":"Device Output '
      + 'Limits","description":"Limits of the measured values output by the '
      + 'device. The limits depend on the device type, measurement program '
      + 'and/or scan pattern.","type":"object"}'
    );

    Example : (''
      + '{"background_radiation_maximum":0,"amplitude_minimum":0.0,"deviation_m'
      + 'aximum":32767,"reflectance_maximum":100.0,"deviation_minimum":-1,"rang'
      + 'e_maximum":10000.0,"mta_zone_count_maximum":7,"range_minimum":2.9,"ref'
      + 'lectance_minimum":-100.0,"background_radiation_minimum":0,"amplitude_m'
      + 'aximum":100.0}'
    );
  );

// Details about the devices used to acquire the point cloud
const
  RDB_RIEGL_DEVICES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.devices';
    Title       : 'Devices Information';
    Description : 'Details about the devices used to acquire the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","title":"Devices '
      + 'Information","description":"Details about the devices used to acquire '
      + 'the point cloud (e.g. when merging point clouds of different devices)"'
      + ',"items":{"properties":{"serial_number":{"description":"Device serial '
      + 'number (e.g. '
      + 'S2221234)","type":"string"},"channel_text":{"description":"Optional '
      + 'channel description (e.g. ''Green Channel'' for multi-channel '
      + 'devices)","type":"string"},"device_build":{"description":"Device build'
      + ' variant","type":"string"},"signed":{"description":"Flag that is set '
      + 'when the original ''riegl.device'' entry in the source file was '
      + 'correctly '
      + 'signed.","type":"boolean"},"device_type":{"description":"Device type '
      + 'identifier (e.g. VZ-400i)","type":"string"},"channel_number":{"minimum'
      + '":0,"exclusiveMinimum":false,"description":"Laser channel number (not '
      + 'defined or 0: single channel '
      + 'device)","type":"integer"},"device_name":{"description":"Optional '
      + 'device name (e.g. ''Scanner 1'' for multi-scanner systems)","type":"stri'
      + 'ng"}},"required":["device_type","serial_number"],"type":"object"},"typ'
      + 'e":"array"}'
    );

    Example : (''
      + '[{"serial_number":"S2221234","channel_text":"","device_build":"","sign'
      + 'ed":false,"device_type":"VZ-400i","channel_number":0,"device_name":"Sc'
      + 'anner 1"},{"serial_number":"S2222680","channel_text":"","device_build"'
      + ':"","signed":true,"device_type":"VQ-1560i-DW","channel_number":1,"devi'
      + 'ce_name":"Scanner 2"},{"serial_number":"S2222680","channel_text":"","d'
      + 'evice_build":"","signed":true,"device_type":"VQ-1560i-DW","channel_num'
      + 'ber":2,"device_name":"Scanner 3"}]'
    );
  );

// Dyntrig
const
  RDB_RIEGL_DYNTRIG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.dyntrig';
    Title       : 'Dyntrig';
    Description : 'Dyntrig';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"of'
      + 'fset":{"description":"Offset in units of dB, for calculation of line",'
      + '"type":"number"},"tab":{"maxItems":128,"minItems":1,"description":"...'
      + '","items":{"properties":{"dec1":{"description":"Decay of post-trigger '
      + 'threshold after del1 in units of '
      + 'dB/m","type":"number"},"del1":{"description":"Length of constant '
      + 'post-trigger threshold elevation in units of '
      + 'm","type":"number"},"del2":{"description":"Length of constant '
      + 'pre-trigger threshold elevation in units of '
      + 'm","type":"number"},"thra1":{"description":"Post-trigger threshold in '
      + 'units of dB","type":"number"},"dec2":{"description":"Rise of '
      + 'pre-trigger threshold after del2 in units of '
      + 'dB/m","type":"number"},"thra2":{"description":"Pre-trigger threshold '
      + 'in units of dB","type":"number"}},"description":"...","required":["thr'
      + 'a1","del1","dec1","thra2","del2","dec2"],"type":"object"},"type":"arra'
      + 'y"},"pre":{"properties":{"a":{"maxItems":2080,"minItems":1,"descriptio'
      + 'n":"...","items":{"type":"number"},"type":"array"},"nc":{"maximum":255'
      + ',"description":"Number of '
      + 'entries","minimum":0,"type":"integer"}},"description":"Dyntrig pre val'
      + 'ues","required":["nc","a"],"type":"object"},"post":{"properties":{"a":'
      + '{"maxItems":2080,"minItems":1,"description":"...","items":{"type":"num'
      + 'ber"},"type":"array"},"nc":{"maximum":255,"description":"Number of '
      + 'entries","minimum":0,"type":"integer"}},"description":"Dyntrig post va'
      + 'lues","required":["nc","a"],"type":"object"},"scale":{"description":"S'
      + 'cale in units of dB, for calculation of line: line number N=(amplitude'
      + '-offset)/scale","type":"number"}},"title":"Dyntrig","description":"Dyn'
      + 'trig"}'
    );

    Example : (''
      + '{"offset":0.0,"tab":[{"dec1":0.0,"del1":0.0,"del2":0.0,"thra1":0.0,"de'
      + 'c2":0.0,"thra2":0.0}],"pre":{"a":[78,86,126,134,31],"nc":128},"post":{'
      + '"a":[78,86,126,134,31],"nc":128},"scale":1.0}'
    );
  );

// Details about echo files
const
  RDB_RIEGL_ECHO_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.echo_info';
    Title       : 'Echo Information';
    Description : 'Details about echo files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"echo_file":{"properties":{"file_uuid":{"description":"'
      + 'File''s Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Echo file '
      + 'extension, without the leading dot","type":"string"}},"required":["fil'
      + 'e_extension"],"type":"object"}},"title":"Echo '
      + 'Information","description":"Details about echo files","required":["ech'
      + 'o_file"],"type":"object","$schema":"http://json-schema.org/draft-04/sc'
      + 'hema#"}'
    );

    Example : (''
      + '{"echo_file":{"file_uuid":"26a03615-67c0-4bea-8fe8-c577378fe661","file'
      + '_extension":"owp"}}'
    );
  );

// Details for exponential decomposition of full waveform data
const
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.exponential_decomposition';
    Title       : 'Exponential Decomposition';
    Description : 'Details for exponential decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Exponential Decomposition","description":"Details for '
      + 'exponential decomposition of full waveform data","type":"object","defi'
      + 'nitions":{"channel":{"properties":{"parameter":{"properties":{"A":{"de'
      + 'scription":"real part of amplitude factor in units of full-scale","ite'
      + 'ms":{"type":"number"},"type":"array"},"gamma":{"description":"decay in'
      + ' 1/second","items":{"type":"number"},"type":"array"},"omega":{"descrip'
      + 'tion":"angular frequency in Hz","items":{"type":"number"},"type":"arra'
      + 'y"},"B":{"description":"imaginary part of amplitude factor in units of'
      + ' full-scale","items":{"type":"number"},"type":"array"}},"description":'
      + '"parameters of the syswave exponential sum","required":["A","B","gamma'
      + '","omega"],"type":"object"},"a_lin":{"maximum":1,"exclusiveMaximum":fa'
      + 'lse,"exclusiveMinimum":false,"description":"relative linear amplitude '
      + 'range '
      + '[0..1]","type":"number","minimum":0},"scale":{"description":"amplitude'
      + ' calibration","type":"number"},"delay":{"description":"delay '
      + 'calibration in seconds","type":"number"}},"required":["delay","scale",'
      + '"parameter"],"type":"object"}},"$schema":"http://json-schema.org/draft'
      + '-04/schema#","patternProperties":{"^[0-9]+$":{"$ref":"#/definitions/ch'
      + 'annel","description":"one field per channel, field name is channel '
      + 'index"}},"additionalProperties":false}'
    );

    Example : (''
      + '{"1":{"parameter":{"A":[0.9,0.3,-1.3],"gamma":[-1094726528.0,-76956275'
      + '2.0,-848000064.0],"omega":[352020896.0,3647927552.0,-1977987072.0],"B"'
      + ':[-3.9,0.0,-0.3]},"a_lin":0.9,"scale":1.0,"delay":3.5e-09},"0":{"param'
      + 'eter":{"A":[0.9772450923919678,0.3354335129261017,-1.312678575515747],'
      + '"gamma":[-1094726528.0,-769562752.0,-848000064.0],"omega":[352020896.0'
      + ',3647927552.0,-1977987072.0],"B":[-3.9813032150268555,0.08622030913829'
      + '803,-0.3152860999107361]},"a_lin":0.27,"scale":1.0,"delay":3.783458418'
      + '887631e-09}}'
    );
  );

// Details for Gaussian decomposition of full waveform data
const
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.gaussian_decomposition';
    Title       : 'Gaussian Decomposition';
    Description : 'Details for Gaussian decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"amplitude_lsb_low_power":{"items":{"type":"number"},"t'
      + 'ype":"array"},"amplitude_db":{"items":{"type":"number"},"type":"array"'
      + '},"amplitude_lsb_high_power":{"items":{"type":"number"},"type":"array"'
      + '},"range_offset_sec_low_power":{"items":{"type":"number"},"type":"arra'
      + 'y"},"range_offset_sec_high_power":{"items":{"type":"number"},"type":"a'
      + 'rray"}},"title":"Gaussian '
      + 'Decomposition","description":"riegl.gaussian_decomposition contains '
      + 'information relevant for extracting calibrated amplitudes and '
      + 'calibrated ranges from a Gaussian decomposition of full waveform data.'
      + ' This information is contained in a table with five columns. Two '
      + 'columns are to be used as input: amplitude_lsb_low_power and '
      + 'amplitude_lsb_high_power. The other three columns provide the outputs.'
      + ' Amplitude_db gives the calibrated amplitude in the optical regime in '
      + 'decibels. The range offset columns provide additive range offsets, '
      + 'given in units of seconds, for each channel.","required":["amplitude_l'
      + 'sb_low_power","amplitude_lsb_high_power","amplitude_db","range_offset_'
      + 'sec_low_power","range_offset_sec_high_power"],"type":"object","$schema'
      + '":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"amplitude_lsb_low_power":[],"amplitude_db":[],"amplitude_lsb_high_po'
      + 'wer":[],"range_offset_sec_low_power":[],"range_offset_sec_high_power":'
      + '[]}'
    );
  );

// Point cloud georeferencing information
const
  RDB_RIEGL_GEO_TAG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geo_tag';
    Title       : 'Geo Tag';
    Description : 'Point cloud georeferencing information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"cr'
      + 's":{"properties":{"name":{"description":"Coordinate reference system '
      + 'name","type":"string"},"wkt":{"description":"\"Well-Known Text\" '
      + 'string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w'
      + 'kt-crs)","type":"string"},"epsg":{"minimum":0,"description":"EPSG '
      + 'code","type":"integer"}},"description":"Global Coordinate Reference '
      + 'System. Please note that only 3D Cartesian Coordinate Systems are allo'
      + 'wed.","type":"object"},"pose":{"maxItems":4,"minItems":4,"description"'
      + ':"Coordinate Transformation Matrix to transform from File Coordinate '
      + 'System to Global Coordinate Reference System. 4x4 matrix stored as two'
      + ' dimensional array, row major order.","items":{"maxItems":4,"minItems"'
      + ':4,"description":"rows","items":{"description":"columns","type":"numbe'
      + 'r"},"type":"array"},"type":"array"}},"title":"Geo '
      + 'Tag","description":"Point cloud georeferencing '
      + 'information","type":"object"}'
    );

    Example : (''
      + '{"crs":{"name":"WGS84 Geocentric","wkt":"GEOCCS[\"WGS84 Geocentric\",D'
      + 'ATUM[\"WGS84\",SPHEROID[\"WGS84\",6378137.000,298.257223563,AUTHORITY['
      + '\"EPSG\",\"7030\"]],AUTHORITY[\"EPSG\",\"6326\"]],PRIMEM[\"Greenwich\"'
      + ',0.0000000000000000,AUTHORITY[\"EPSG\",\"8901\"]],UNIT[\"Meter\",1.000'
      + '00000000000000000,AUTHORITY[\"EPSG\",\"9001\"]],AXIS[\"X\",OTHER],AXIS'
      + '[\"Y\",EAST],AXIS[\"Z\",NORTH],AUTHORITY[\"EPSG\",\"4978\"]]","epsg":4'
      + '978},"pose":[[-0.269827776749716,-0.723017716139738,0.635954678449952,'
      + '4063882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847'
      + ',1138787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196'
      + '],[0.0,0.0,0.0,1.0]]}'
    );
  );

// Geometric scale factor applied to point coordinates
const
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geometric_scale_factor';
    Title       : 'Geometric Scale Factor';
    Description : 'Geometric scale factor applied to point coordinates';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","minimum":0,"excl'
      + 'usiveMinimum":true,"description":"Geometric scale factor applied to '
      + 'point coordinates","type":"number"}'
    );

    Example : (''
      + '1.0'
    );
  );

// Parameters used for georeferencing of the point cloud
const
  RDB_RIEGL_GEOREFERENCING_PARAMETERS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.georeferencing_parameters';
    Title       : 'Georeferencing Parameters';
    Description : 'Parameters used for georeferencing of the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"tr'
      + 'ajectory_file":{"properties":{"file_uuid":{"description":"File''s '
      + 'Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Trajectory '
      + 'file extension, without the leading '
      + 'dot","type":"string"}},"description":"Trajectory data used for '
      + 'georeferencing of the point cloud","required":["file_extension"],"type'
      + '":"object"},"socs_to_rocs_matrix":{"maxItems":4,"minItems":4,"descript'
      + 'ion":"Coordinate Transformation Matrix to transform from Scanner''s Own'
      + ' Coordinate System to Record Coordinate System. 4x4 matrix stored as '
      + 'two dimensional array, row major order.","items":{"maxItems":4,"minIte'
      + 'ms":4,"description":"rows","items":{"description":"columns","type":"nu'
      + 'mber"},"type":"array"},"type":"array"},"trajectory_offsets":{"properti'
      + 'es":{"offset_east":{"description":"[m]","type":"number"},"offset_pitch'
      + '":{"description":"[deg]","type":"number"},"version":{"description":"Me'
      + 'aning of offset values and how to apply them; version 0: '
      + 'Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), '
      + 'version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch'
      + ')*Rx(offset_roll)","type":"integer"},"offset_north":{"description":"[m'
      + ']","type":"number"},"offset_height":{"description":"[m]","type":"numbe'
      + 'r"},"offset_yaw":{"description":"[deg]","type":"number"},"offset_time"'
      + ':{"description":"[s]","type":"number"},"offset_roll":{"description":"['
      + 'deg]","type":"number"}},"description":"Correction offsets applied to '
      + 'the trajectory data","type":"object"},"socs_to_body_matrix":{"maxItems'
      + '":4,"minItems":4,"description":"Coordinate Transformation Matrix to '
      + 'transform from Scanner''s Own Coordinate System to Body Coordinate '
      + 'System. 4x4 matrix stored as two dimensional array, row major order.",'
      + '"items":{"maxItems":4,"minItems":4,"description":"rows","items":{"desc'
      + 'ription":"columns","type":"number"},"type":"array"},"type":"array"},"b'
      + 'ody_coordinate_system_type":{"enum":["NED","ENU"],"description":"BODY '
      + 'coordinate frame (NED: North-East-Down, ENU: East-North-Up), default: '
      + 'NED","type":"string"}},"title":"Georeferencing '
      + 'Parameters","description":"Parameters used for georeferencing of the '
      + 'point cloud","type":"object"}'
    );

    Example : (''
      + '{"trajectory_file":{"file_uuid":"93a03615-66c0-4bea-8ff8-c577378fe660"'
      + ',"file_extension":"pofx"},"trajectory_offsets":{"offset_east":0.15,"of'
      + 'fset_pitch":0.01,"version":0,"offset_north":0.07,"offset_height":-0.2,'
      + '"offset_yaw":-0.45,"offset_time":18.007,"offset_roll":0.03},"socs_to_b'
      + 'ody_matrix":[[-0.269827776749716,-0.723017716139738,0.635954678449952,'
      + '0.0],[0.962908599449764,-0.20260517250352,0.178208229833847,0.0],[0.0,'
      + '0.660451759194338,0.7508684796801,0.0],[0.0,0.0,0.0,1.0]],"body_coordi'
      + 'nate_system_type":"NED"}'
    );
  );

// Map of item names
const
  RDB_RIEGL_ITEM_NAMES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.item_names';
    Title       : 'Item Names';
    Description : 'Map of item names';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Item Names","description":"Map of item names","type":"object'
      + '","$schema":"http://json-schema.org/draft-04/schema#","patternProperti'
      + 'es":{"^-?[0-9]+$":{"description":"One field per item, field name is '
      + 'item id, field value is item '
      + 'name","type":"string"}},"additionalProperties":false}'
    );

    Example : (''
      + '{"-1":"Name of item with id -1","47":"Name of item with id '
      + '47","1":"Name of item with id 1","2":"Name of item with id 2"}'
    );
  );

// License keys for software features
const
  RDB_RIEGL_LICENSES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.licenses';
    Title       : 'Software License Keys';
    Description : 'License keys for software features';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Software License Keys","description":"License keys for '
      + 'software features","type":"object","$schema":"http://json-schema.org/d'
      + 'raft-04/schema#","patternProperties":{"^.*$":{"minItems":1,"descriptio'
      + 'n":"Each field of the object represents a feature and holds a list of '
      + 'license keys, where the field name is the feature '
      + 'name.","items":{"description":"License key (example: ''46AE032A - '
      + '39882AC4 - 9EC0A184 - 6F163D73'')","type":"string"},"type":"array"}},"a'
      + 'dditionalProperties":false}'
    );

    Example : (''
      + '{"Full Waveform Analysis Topography with GPU support":["8AB44126 - '
      + '23B92250 - 16E2689F - 34EF7E7B"],"Full Waveform Analysis '
      + 'Topography":["0FD5FF07 - 011A1255 - 9F76CACA - 8D2ED557"],"MTA '
      + 'resolution":["468E020A - 39A922E4 - B681A184 - '
      + '673E3D72"],"Georeferencing":["46AE032A - 39882AC4 - 9EC0A184 - '
      + '6F163D73"]}'
    );
  );

// Parameters for MTA processing
const
  RDB_RIEGL_MTA_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.mta_settings';
    Title       : 'MTA Settings';
    Description : 'Parameters for MTA processing';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"zo'
      + 'ne_width":{"minimum":0,"description":"Width of a MTA zone in meter.","'
      + 'type":"number"},"modulation_depth":{"minimum":0,"description":"Depth '
      + 'of pulse position modulation in meter.","type":"number"},"zone_count":'
      + '{"maximum":255,"minimum":0,"description":"Maximum number of MTA '
      + 'zones.","type":"integer"}},"title":"MTA '
      + 'Settings","description":"Parameters for MTA '
      + 'processing","type":"object"}'
    );

    Example : (''
      + '{"zone_width":149.896225,"modulation_depth":9.368514,"zone_count":23}'
    );
  );

// Lookup table for range correction based on raw range
const
  RDB_RIEGL_NEAR_RANGE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.near_range_correction';
    Title       : 'Near Range Correction Table';
    Description : 'Lookup table for range correction based on raw range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"content":{"maxItems":2000,"minItems":1,"description":"'
      + 'Correction value [m] to be added to the raw range","items":{"type":"nu'
      + 'mber"},"type":"array"},"delta":{"description":"Delta between table '
      + 'entries [m], first entry is at range = 0 '
      + 'm","type":"number"}},"title":"Near Range Correction '
      + 'Table","description":"Lookup table for range correction based on raw r'
      + 'ange","required":["delta","content"],"type":"object","$schema":"http:/'
      + '/json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"content":[0.0],"delta":0.512}'
    );
  );

// Standard deviation for range and amplitude as a function of amplitude
const
  RDB_RIEGL_NOISE_ESTIMATES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.noise_estimates';
    Title       : 'Noise Estimates';
    Description : 'Standard deviation for range and amplitude as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"range_sigma":{"description":"Sigma range [m]","items":'
      + '{"type":"number"},"type":"array"},"amplitude":{"description":"Amplitud'
      + 'e [dB]","items":{"type":"number"},"type":"array"},"amplitude_sigma":{"'
      + 'description":"Sigma amplitude '
      + '[dB]","items":{"type":"number"},"type":"array"}},"title":"Noise '
      + 'Estimates","description":"Standard deviation for range and amplitude '
      + 'as a function of amplitude","required":["amplitude","range_sigma","amp'
      + 'litude_sigma"],"type":"object","$schema":"http://json-schema.org/draft'
      + '-04/schema#"}'
    );

    Example : (''
      + '{"range_sigma":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.018,'
      + '0.016,0.014],"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0'
      + '],"amplitude_sigma":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.'
      + '432,0.39,0.354]}'
    );
  );

// Notch filter parameters for window glass echoes
const
  RDB_RIEGL_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.notch_filter';
    Title       : 'Notch Filter';
    Description : 'Notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"range_maximum":{"description":"Maximum range '
      + '[m]","type":"number"},"range_minimum":{"description":"Minimum range '
      + '[m]","type":"number"},"amplitude_maximum":{"description":"Maximum '
      + 'amplitude [dB]","minimum":0,"type":"number"}},"title":"Notch '
      + 'Filter","description":"Notch filter parameters for window glass echoes'
      + '","required":["range_minimum","range_maximum","amplitude_maximum"],"ty'
      + 'pe":"object","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"range_maximum":0.2,"range_minimum":-0.5,"amplitude_maximum":18.0}'
    );
  );

// Details about the pixels contained in the file
const
  RDB_RIEGL_PIXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pixel_info';
    Title       : 'Pixel Information';
    Description : 'Details about the pixels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"size_llcs":{"$ref":"#/definitions/pixel_size","descrip'
      + 'tion":"Size of pixels in a locally levelled cartesian coordinate '
      + 'system (xy). This is only used for pixels based on a map projection."}'
      + ',"size":{"$ref":"#/definitions/pixel_size","description":"Size of '
      + 'pixels in file coordinate system."}},"title":"Pixel '
      + 'Information","description":"Details about the pixels contained in the '
      + 'file","required":["size"],"type":"object","definitions":{"pixel_size":'
      + '{"maxItems":2,"minItems":2,"description":"Size of '
      + 'pixels.","items":{"minimum":0,"description":"Length of pixel edge [m].'
      + '","type":"number"},"type":"array"}},"$schema":"http://json-schema.org/'
      + 'draft-04/schema#"}'
    );

    Example : (''
      + '{"size_llcs":[0.5156575252891171,0.5130835356683303],"size":[0.5971642'
      + '834779395,0.5971642834779395]}'
    );
  );

// Details about the plane patch matching process
const
  RDB_RIEGL_PLANE_PATCH_MATCHING : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_matching';
    Title       : 'Plane Patch Matching';
    Description : 'Details about the plane patch matching process';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"plane_patch_file_one":{"$ref":"#/definitions/file_refe'
      + 'rence","description":"Reference to the plane patch file one"},"plane_p'
      + 'atch_file_two":{"$ref":"#/definitions/file_reference","description":"R'
      + 'eference to the plane patch file two"}},"title":"Plane Patch '
      + 'Matching","description":"Details about the plane patch matching proces'
      + 's","required":["plane_patch_file_one","plane_patch_file_two"],"type":"'
      + 'object","definitions":{"file_reference":{"properties":{"file_uuid":{"d'
      + 'escription":"Plane patch file''s Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"file_path":{"description":"Path of the plane '
      + 'patch file relative to the match '
      + 'file","type":"string"}},"description":"Reference to a plane patch file'
      + '","required":["file_uuid","file_path"],"type":"object"}},"$schema":"ht'
      + 'tp://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"plane_patch_file_one":{"file_uuid":"810f5d57-eccf-49ed-b07a-0cdd109b'
      + '4213","file_path":"Record009_Line001/191025_121410_Scanner_1.ptch"},"p'
      + 'lane_patch_file_two":{"file_uuid":"fa47d509-a64e-49ce-8b14-ff3130fbefa'
      + '9","file_path":"project.ptch"}}'
    );
  );

// Statistics about plane patches found by plane patch extractor
const
  RDB_RIEGL_PLANE_PATCH_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_statistics';
    Title       : 'Plane Patch Statistics';
    Description : 'Statistics about plane patches found by plane patch extractor';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"to'
      + 'tal_area":{"description":"sum of all plane patch areas [m\u00b2]","typ'
      + 'e":"number"},"total_horizontal_area":{"description":"sum of all plane '
      + 'patch areas projected to horizontal plane '
      + '[m\u00b2]","type":"number"}},"title":"Plane Patch '
      + 'Statistics","description":"Statistics about plane patches found by '
      + 'plane patch extractor","type":"object"}'
    );

    Example : (''
      + '{"total_area":14007.965,"total_horizontal_area":13954.601}'
    );
  );

// Settings and classes for plane slope classification
const
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_slope_class_info';
    Title       : 'Plane Slope Class Info';
    Description : 'Settings and classes for plane slope classification';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"settings":{"description":"Classification settings, '
      + 'details see documentation of rdbplanes","oneOf":[{"$ref":"#/definition'
      + 's/method-1"},{"$ref":"#/definitions/method-2"}],"type":"object"},"clas'
      + 'ses":{"additionalProperties":false,"patternProperties":{"^[0-9]+$":{"d'
      + 'escription":"one field per class, field name is class number, field '
      + 'value is class name","type":"string"}},"description":"Class definition'
      + ' table","type":"object"}},"title":"Plane Slope Class '
      + 'Info","description":"Settings and classes for plane slope classificati'
      + 'on","required":["settings","classes"],"type":"object","definitions":{"'
      + 'method-2":{"properties":{"sloping_plane_classes_maximum_angle":{"maxim'
      + 'um":360.0,"minimum":-360.0,"description":"maximum inclination angle of'
      + ' sloping plane patches [deg]","type":"number"},"sloping_plane_classes_'
      + 'minimum_angle":{"maximum":360.0,"minimum":-360.0,"description":"minimu'
      + 'm inclination angle of sloping plane patches [deg]","type":"number"},"'
      + 'plane_classification_method":{"maximum":2,"minimum":2,"description":"m'
      + 'ethod ID (=2)","type":"integer"}},"description":"Classification method'
      + ' 2","required":["plane_classification_method","sloping_plane_classes_m'
      + 'inimum_angle","sloping_plane_classes_maximum_angle"],"type":"object"},'
      + '"method-1":{"properties":{"maximum_inclination_angle_horizontal":{"max'
      + 'imum":360.0,"minimum":-360.0,"description":"maximum inclination angle '
      + 'of horizontal plane patches [deg]","type":"number"},"plane_classificat'
      + 'ion_method":{"maximum":1,"minimum":1,"description":"method ID '
      + '(=1)","type":"integer"}},"description":"Classification method 1","requ'
      + 'ired":["plane_classification_method","maximum_inclination_angle_horizo'
      + 'ntal"],"type":"object"}},"$schema":"http://json-schema.org/draft-04/sc'
      + 'hema#"}'
    );

    Example : (''
      + '{"settings":{"sloping_plane_classes_maximum_angle":70.0,"sloping_plane'
      + '_classes_minimum_angle":10.0,"plane_classification_method":2},"classes'
      + '":{"12":"sloping, pointing down and north","9":"vertical, pointing '
      + 'west","3":"sloping, pointing up and south","6":"vertical, pointing '
      + 'east","13":"sloping, pointing down and west","7":"vertical, pointing '
      + 'south","4":"sloping, pointing up and north","11":"sloping, pointing '
      + 'down and south","1":"horizontal, pointing up","2":"sloping, pointing '
      + 'up and east","8":"vertical, pointing north","14":"horizontal, pointing'
      + ' down","10":"sloping, pointing down and east","5":"sloping, pointing '
      + 'up and west"}}'
    );
  );

// Grouping and sorting of point attributes for visualization purposes
const
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.point_attribute_groups';
    Title       : 'Point Attribute Groups';
    Description : 'Grouping and sorting of point attributes for visualization purposes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Point Attribute Groups","description":"Grouping and sorting '
      + 'of point attributes for visualization purposes","type":"object","$sche'
      + 'ma":"http://json-schema.org/draft-04/schema#","patternProperties":{"^.'
      + '*$":{"minItems":1,"description":"Each field of the object represents a'
      + ' point attribute group and holds a list of point attributes, where the'
      + ' field name is the group name.","items":{"description":"Point '
      + 'attribute full name or name pattern (perl regular expression syntax)",'
      + '"type":"string"},"type":"array"}},"additionalProperties":false}'
    );

    Example : (''
      + '{"Time":["riegl.timestamp"],"Secondary '
      + 'Attributes":["riegl.mirror_facet","riegl.waveform_available"],"Other '
      + 'Attributes":["riegl.selected","riegl.visible"],"Primary Attributes":["'
      + 'riegl.reflectance","riegl.amplitude","riegl.deviation"],"Coordinates/V'
      + 'ectors":["riegl.xyz","riegl.range","riegl.theta","riegl.phi"]}'
    );
  );

// Details about point cloud files
const
  RDB_RIEGL_POINTCLOUD_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pointcloud_info';
    Title       : 'Point Cloud Information';
    Description : 'Details about point cloud files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"fi'
      + 'eld_of_application":{"enum":["unknown","SLS","TLS","KLS","MLS","ULS","'
      + 'ALS","BLS","ILS"],"description":"Field of application","type":"string"'
      + '},"comments":{"description":"Comments","type":"string"},"project":{"de'
      + 'scription":"Project name","type":"string"}},"title":"Point Cloud '
      + 'Information","description":"Details about point cloud '
      + 'files","type":"object"}'
    );

    Example : (''
      + '{"field_of_application":"ALS","comments":"Line 3","project":"Campaign '
      + '4"}'
    );
  );

// Estimated position and orientation information
const
  RDB_RIEGL_POSE_ESTIMATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_estimation';
    Title       : 'Pose Estimation';
    Description : 'Estimated position and orientation information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"position":{"properties":{"horizontal_accuracy":{"minim'
      + 'um":0,"exclusiveMinimum":true,"description":"Horizontal accuracy '
      + '[m]","type":"number"},"coordinate_2":{"description":"Coordinate 2 as '
      + 'defined by axis 2 of the specified CRS (e.g., Y, '
      + 'Longitude)","type":"number"},"coordinate_3":{"description":"Coordinate'
      + ' 3 as defined by axis 3 of the specified CRS (e.g., Z, Altitude)","typ'
      + 'e":"number"},"crs":{"properties":{"wkt":{"description":"\"Well-Known '
      + 'Text\" string, OGC WKT dialect (see http://www.opengeospatial.org/stan'
      + 'dards/wkt-crs)","type":"string"},"epsg":{"minimum":0,"description":"EP'
      + 'SG code","type":"integer"}},"description":"Global Coordinate Reference'
      + ' System","required":["epsg"],"type":"object"},"coordinate_1":{"descrip'
      + 'tion":"Coordinate 1 as defined by axis 1 of the specified CRS (e.g., '
      + 'X, Latitude)","type":"number"},"vertical_accuracy":{"minimum":0,"exclu'
      + 'siveMinimum":true,"description":"Vertical accuracy '
      + '[m]","type":"number"}},"description":"Position coordinates and '
      + 'position accuracy values as measured by GNSS in the specified '
      + 'Coordinate Reference System (CRS)","required":["coordinate_1","coordin'
      + 'ate_2","coordinate_3","horizontal_accuracy","vertical_accuracy","crs"]'
      + ',"type":"object"},"orientation":{"properties":{"yaw":{"maximum":360,"m'
      + 'inimum":-360,"description":"Yaw angle about scanner Z-axis [deg]","typ'
      + 'e":"number"},"roll":{"maximum":360,"minimum":-360,"description":"Roll '
      + 'angle about scanner X-axis [deg]","type":"number"},"yaw_accuracy":{"mi'
      + 'nimum":0,"exclusiveMinimum":true,"description":"Yaw angle accuracy [de'
      + 'g]","type":"number"},"roll_accuracy":{"minimum":0,"exclusiveMinimum":t'
      + 'rue,"description":"Roll angle accuracy [deg]","type":"number"},"pitch_'
      + 'accuracy":{"minimum":0,"exclusiveMinimum":true,"description":"Pitch '
      + 'angle accuracy [deg]","type":"number"},"pitch":{"maximum":360,"minimum'
      + '":-360,"description":"Pitch angle about scanner Y-axis '
      + '[deg]","type":"number"}},"description":"Orientation values and '
      + 'orientation accuracies, measured with IMU or inclination sensors.","re'
      + 'quired":["roll","pitch","yaw","roll_accuracy","pitch_accuracy","yaw_ac'
      + 'curacy"],"type":"object"},"barometric_height_amsl":{"description":"Alt'
      + 'itude determined based on the atmospheric pressure according to the '
      + 'standard atmosphere laws [m].","type":"number"}},"title":"Pose '
      + 'Estimation","description":"Estimated position and orientation '
      + 'information as measured by GNSS, IMU or inclination sensors","required'
      + '":["orientation"],"type":"object","$schema":"http://json-schema.org/dr'
      + 'aft-04/schema#"}'
    );

    Example : (''
      + '{"position":{"horizontal_accuracy":0.810699999332428,"coordinate_2":15'
      + '.645033406,"coordinate_3":362.7124938964844,"crs":{"wkt":"GEOGCS[\"WGS'
      + '84 / Geographic\",DATUM[\"WGS84\",SPHEROID[\"WGS84\",6378137.000,298.2'
      + '57223563,AUTHORITY[\"EPSG\",\"7030\"]],AUTHORITY[\"EPSG\",\"6326\"]],P'
      + 'RIMEM[\"Greenwich\",0.0000000000000000,AUTHORITY[\"EPSG\",\"8901\"]],U'
      + 'NIT[\"Degree\",0.01745329251994329547,AUTHORITY[\"EPSG\",\"9102\"]],AX'
      + 'IS[\"Latitude\",NORTH],AXIS[\"Longitude\",EAST],AUTHORITY[\"EPSG\",\"4'
      + '979\"]]","epsg":4979},"coordinate_1":48.655799473,"vertical_accuracy":'
      + '1.3314999341964722},"orientation":{"yaw":101.87293630292045,"roll":3.1'
      + '4743073066123,"yaw_accuracy":1.0094337839368757,"roll_accuracy":0.0094'
      + '33783936875745,"pitch_accuracy":0.009433783936875745,"pitch":1.5091530'
      + '24827064},"barometric_height_amsl":386.7457796227932}'
    );
  );

// Details on position and orientation sensors
const
  RDB_RIEGL_POSE_SENSORS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_sensors';
    Title       : 'Pose Sensors';
    Description : 'Details on position and orientation sensors';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"accelerometer":{"properties":{"origin":{"$ref":"#/defi'
      + 'nitions/vector","description":"Sensor origin in SOCS [m] at frame '
      + 'angle = '
      + '0"},"offset":{"$ref":"#/definitions/vector","description":"Value to be'
      + ' subtracted from raw measurement values"},"z_axis":{"$ref":"#/definiti'
      + 'ons/vector","description":"Sensitive Z axis of sensor at frame angle ='
      + ' 0"},"relative_nonlinearity":{"$ref":"#/definitions/vector","descripti'
      + 'on":"Relative nonlinearity, dimensionless"},"unit":{"minimum":0,"exclu'
      + 'siveMinimum":true,"description":"Unit of raw data and calibration '
      + 'values, 1 LSB in 9.81 m/s\u00b2","type":"number"},"x_axis":{"$ref":"#/'
      + 'definitions/vector","description":"Sensitive X axis of sensor at frame'
      + ' angle = '
      + '0"},"y_axis":{"$ref":"#/definitions/vector","description":"Sensitive Y'
      + ' axis of sensor at frame angle = 0"}},"description":"Accelerometer det'
      + 'ails","required":["unit","x_axis","y_axis","z_axis","offset","origin",'
      + '"relative_nonlinearity"],"type":"object"},"magnetic_field_sensor":{"pr'
      + 'operties":{"offset":{"$ref":"#/definitions/vector","description":"Valu'
      + 'e to be subtracted from raw measurement values"},"z_axis":{"$ref":"#/d'
      + 'efinitions/vector","description":"Sensitive Z axis of sensor at frame '
      + 'angle = 0"},"relative_nonlinearity":{"$ref":"#/definitions/vector","de'
      + 'scription":"Relative nonlinearity, dimensionless"},"fixed":{"$ref":"#/'
      + 'definitions/vector","description":"Distortion of magnetic field caused'
      + ' by non-rotating scanner '
      + 'part"},"unit":{"minimum":0,"exclusiveMinimum":true,"description":"Unit'
      + ' of raw data and calibration values, 1 LSB in nT","type":"number"},"x_'
      + 'axis":{"$ref":"#/definitions/vector","description":"Sensitive X axis '
      + 'of sensor at frame angle = '
      + '0"},"y_axis":{"$ref":"#/definitions/vector","description":"Sensitive Y'
      + ' axis of sensor at frame angle = 0"}},"description":"Magnetic Field '
      + 'Sensor details","required":["unit","x_axis","y_axis","z_axis","offset"'
      + ',"fixed","relative_nonlinearity"],"type":"object"},"gyroscope":{"prope'
      + 'rties":{"origin":{"$ref":"#/definitions/vector","description":"Sensor '
      + 'origin in SOCS [m] at frame angle = '
      + '0"},"offset":{"$ref":"#/definitions/vector","description":"Value to be'
      + ' subtracted from raw measurement values"},"z_axis":{"$ref":"#/definiti'
      + 'ons/vector","description":"Sensitive Z axis of sensor at frame angle ='
      + ' 0"},"relative_nonlinearity":{"$ref":"#/definitions/vector","descripti'
      + 'on":"Relative nonlinearity, dimensionless"},"unit":{"minimum":0,"exclu'
      + 'siveMinimum":true,"description":"Unit of raw data and calibration '
      + 'values, 1 LSB in rad/s","type":"number"},"x_axis":{"$ref":"#/definitio'
      + 'ns/vector","description":"Sensitive X axis of sensor at frame angle = '
      + '0"},"y_axis":{"$ref":"#/definitions/vector","description":"Sensitive Y'
      + ' axis of sensor at frame angle = 0"}},"description":"Gyroscope details'
      + '","required":["unit","x_axis","y_axis","z_axis","offset","origin","rel'
      + 'ative_nonlinearity"],"type":"object"}},"title":"Pose '
      + 'Sensors","description":"Details on position and orientation sensors","'
      + 'required":["gyroscope","accelerometer","magnetic_field_sensor"],"type"'
      + ':"object","definitions":{"vector":{"maxItems":3,"minItems":3,"items":{'
      + '"description":"Index 0=X, 1=Y, 2=Z component","type":"number"},"type":'
      + '"array"}},"$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"accelerometer":{"origin":[0.026900000870227814,-0.03999999910593033,'
      + '-0.08950000256299973],"offset":[-733.3636474609375,58.969032287597656,'
      + '1060.2550048828125],"z_axis":[1.639882206916809,15166.744140625,-116.9'
      + '9742889404297],"relative_nonlinearity":[0.0,0.0,0.0],"unit":6.66666674'
      + '0784422e-05,"x_axis":[-15008.123046875,56.956390380859375,-60.51756668'
      + '09082],"y_axis":[-7.027288913726807,-44.12333679199219,14952.370117187'
      + '5]},"magnetic_field_sensor":{"offset":[-23812.052734375,5606.576660156'
      + '25,2493.28125],"z_axis":[0.00041987866279669106,7.876977906562388e-05,'
      + '0.011407104320824146],"relative_nonlinearity":[0.0,0.0,0.0],"fixed":[-'
      + '1576.010498046875,1596.081787109375,0.0],"unit":91.74311828613281,"x_a'
      + 'xis":[-0.011162743903696537,-2.315962774446234e-05,0.00016818844596855'
      + '342],"y_axis":[0.00027888521435670555,-0.011427424848079681,-5.2048297'
      + '22060822e-05]},"gyroscope":{"origin":[0.026900000870227814,-0.03999999'
      + '910593033,-0.08950000256299973],"offset":[-50.92609786987305,146.15643'
      + '310546875,62.4327278137207],"z_axis":[0.555869996547699,119.2213516235'
      + '3516,0.467585027217865],"relative_nonlinearity":[2.888176311444113e-07'
      + ',1.06274164579645e-07,-1.7186295080634935e-39],"unit":0.00014544410805'
      + '683583,"x_axis":[-121.195556640625,0.8219714164733887,0.23130317032337'
      + '19],"y_axis":[-0.440765917301178,-0.7897399663925171,119.5894775390625'
      + ']}}'
    );
  );

// Laser pulse position modulation used for MTA resolution
const
  RDB_RIEGL_PULSE_POSITION_MODULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pulse_position_modulation';
    Title       : 'Pulse Position Modulation';
    Description : 'Laser pulse position modulation used for MTA resolution';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"code_phase_mode":{"maximum":255,"minimum":0,"descripti'
      + 'on":"0: no synchronization, 1: toggle between 2 phases, 2: increment '
      + 'with phase_increment","type":"integer"},"phase_step":{"maximum":255,"m'
      + 'inimum":0,"description":"Step width in phase of modulation code from '
      + 'line to line","type":"integer"},"length":{"maximum":255,"minimum":0,"d'
      + 'escription":"Length of '
      + 'code","type":"integer"},"pulse_interval":{"description":"Explicit '
      + 'table of the pulse position modulation used for MTA resolution. Table '
      + 'gives times between successive laser pulses in seconds.","items":{"min'
      + 'imum":0,"type":"number"},"type":"array"},"num_mod_ampl":{"maximum":255'
      + ',"minimum":0,"description":"Number of different modulation amplitudes '
      + '(2: binary modulation)","type":"integer"}},"title":"Pulse Position '
      + 'Modulation","description":"Laser pulse position modulation used for '
      + 'MTA resolution","required":["length","num_mod_ampl","pulse_interval"],'
      + '"type":"object","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"code_phase_mode":2,"phase_step":5,"length":31,"pulse_interval":[2.75'
      + '9375e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e'
      + '-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.821875e-06,2'
      + '.759375e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.8218'
      + '75e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.821875e-0'
      + '6,2.821875e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.7'
      + '59375e-06,2.821875e-06,2.759375e-06,2.821875e-06],"num_mod_ampl":2}'
    );
  );

// Statistics about target distance wrt. SOCS origin
const
  RDB_RIEGL_RANGE_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.range_statistics';
    Title       : 'Range Statistics';
    Description : 'Statistics about target distance wrt. SOCS origin';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"maximum":{"description":"Maximum '
      + 'value","type":"number"},"average":{"description":"Average '
      + 'value","type":"number"},"std_dev":{"description":"Standard '
      + 'deviation","type":"number"},"minimum":{"description":"Minimum '
      + 'value","type":"number"}},"title":"Range '
      + 'Statistics","description":"Statistics about target distance wrt. SOCS '
      + 'origin","required":["minimum","average","maximum","std_dev"],"type":"o'
      + 'bject","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"maximum":574.35,"average":15.49738,"std_dev":24.349,"minimum":0.919}'
    );
  );

// Receiver Internals
const
  RDB_RIEGL_RECEIVER_INTERNALS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.receiver_internals';
    Title       : 'Receiver Internals';
    Description : 'Receiver Internals';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"nt":{"maximum":255,"description":"Number of traces","m'
      + 'inimum":0,"type":"integer"},"mw":{"maximum":4095,"description":"Maximu'
      + 'm weight","exclusiveMinimum":true,"minimum":0,"type":"number"},"ex":{"'
      + 'description":"DEPRECATED, use ''riegl.exponential_decomposition'' instea'
      + 'd","type":"object"},"t":{"additionalProperties":false,"patternProperti'
      + 'es":{"^[0-9]+$":{"$ref":"#/definitions/fp","description":"one field '
      + 'per channel, field name is channel '
      + 'index"}},"type":"object"},"si":{"maximum":255,"description":"Start '
      + 'index (hw_start)","minimum":0,"type":"number"},"tbl":{"minItems":1,"de'
      + 'scription":"various internal data","items":{"$ref":"#/definitions/fp_t'
      + 'able"},"type":"array"},"a":{"maxItems":256,"minItems":1,"description":'
      + '"Amplitude [dB]","items":{"type":"number"},"type":"array"},"ns":{"maxi'
      + 'mum":4095,"description":"Number of '
      + 'samples","minimum":0,"type":"integer"},"sr":{"description":"Sample '
      + 'rate [Hz]","exclusiveMinimum":true,"minimum":0,"type":"number"}},"titl'
      + 'e":"Receiver Internals","description":"Receiver Internals","type":"obj'
      + 'ect","definitions":{"fp_table":{"properties":{"nx":{"max":2048,"descri'
      + 'ption":"number of x entries","min":1,"type":"integer"},"ch":{"max":255'
      + ',"description":"channel number","min":0,"type":"integer"},"tv":{"maxIt'
      + 'ems":2048,"minItems":1,"type":"array","items":{"oneOf":[{"$ref":"#/def'
      + 'initions/fp_table_row"},{"type":"number"}]}},"tc":{"max":255,"descript'
      + 'ion":"table data type '
      + 'code","min":0,"type":"integer"},"ny":{"max":2048,"description":"number'
      + ' of y entries","min":1,"type":"integer"}},"required":["ch","tc","nx","'
      + 'ny","tv"],"type":"object","desription":"scanner internal data"},"fp":{'
      + '"properties":{"w":{"maxItems":256,"minItems":1,"items":{"maxItems":5,"'
      + 'minItems":5,"items":{"type":"number"},"type":"array"},"type":"array"},'
      + '"s":{"maxItems":256,"minItems":1,"items":{"maxItems":4096,"minItems":1'
      + ',"items":{"type":"number"},"type":"array"},"type":"array"}},"descripti'
      + 'on":"Fingerprint values","required":["s","w"],"type":"object"},"fp_tab'
      + 'le_row":{"maxItems":2048,"minItems":1,"type":"array","items":{"type":"'
      + 'number"}}},"$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"nt":128,"mw":31,"t":{"1":{"w":[[78,86,126,134,31],[78,86,126,134,31]'
      + '],"s":[[1.23,4.56],[7.89,0.12]]},"0":{"w":[[78,86,126,134,31],[78,86,1'
      + '26,134,31]],"s":[[1.23,4.56],[7.89,0.12]]}},"si":48,"tbl":[{"nx":5,"ch'
      + '":0,"tv":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,5.5]],"tc":1,"ny":2}],"a":[-1.5'
      + '5],"ns":400,"sr":7959997000.0}'
    );
  );

// Lookup table for reflectance calculation based on amplitude and range
const
  RDB_RIEGL_REFLECTANCE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_calculation';
    Title       : 'Reflectance Calculation Table';
    Description : 'Lookup table for reflectance calculation based on amplitude and range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"content":{"maxItems":2000,"minItems":1,"description":"'
      + 'Correction value [dB] to be added to the amplitude","items":{"type":"n'
      + 'umber"},"type":"array"},"delta":{"description":"Delta between table '
      + 'entries [m], first entry is at range = 0 '
      + 'm","type":"number"}},"title":"Reflectance Calculation '
      + 'Table","description":"Lookup table for reflectance calculation based '
      + 'on amplitude and range","required":["delta","content"],"type":"object"'
      + ',"$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"content":[-33.01],"delta":0.150918}'
    );
  );

// Range-dependent and scan-angle-dependent correction of reflectance reading
const
  RDB_RIEGL_REFLECTANCE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_correction';
    Title       : 'Near-Range Reflectance Correction';
    Description : 'Range-dependent and scan-angle-dependent correction of reflectance reading';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"reflectance_correction_db":{"description":"Near range '
      + 'reflectance correction in dB as a function of range over '
      + 'angle","items":{"description":"rows (each array corresponds to a '
      + 'range)","items":{"description":"columns (each value corresponds to an '
      + 'angle)","type":"number"},"type":"array"},"type":"array"},"ranges_m":{"'
      + 'description":"Range [m]","items":{"type":"number"},"type":"array"},"li'
      + 'ne_angles_deg":{"description":"Angle '
      + '[deg]","items":{"type":"number"},"type":"array"}},"title":"Near-range '
      + 'reflectance correction","description":"Range-dependent and '
      + 'scan-angle-dependent correction of reflectance reading","required":["r'
      + 'anges_m","line_angles_deg","reflectance_correction_db"],"type":"object'
      + '","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"reflectance_correction_db":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.'
      + '01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0'
      + '.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],"ra'
      + 'nges_m":[0.0,1.0,2.0,3.0],"line_angles_deg":[0.0,0.5,1.0,1.5,1.0,2.0,2'
      + '.5,3.0,3.5,4.0]}'
    );
  );

// Scan pattern description
const
  RDB_RIEGL_SCAN_PATTERN : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.scan_pattern';
    Title       : 'Scan Pattern';
    Description : 'Scan pattern description';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"se'
      + 'gments":{"properties":{"program":{"$ref":"#/definitions/program"},"lis'
      + 't":{"items":{"properties":{"start":{"maximum":360.0,"minimum":0.0,"des'
      + 'cription":"Start angle in SOCS [deg]","type":"number"},"stop":{"maximu'
      + 'm":720.0,"minimum":0.0,"description":"Stop angle in SOCS [deg]","type"'
      + ':"number"},"increment":{"maximum":90.0,"minimum":0.0,"description":"In'
      + 'crement of angle in SOCS [deg]","type":"number"}},"description":"Line '
      + 'Scan Segment","required":["start","stop","increment"],"type":"object"}'
      + ',"type":"array"}},"description":"Segmented Line Scan Pattern","require'
      + 'd":["list"],"type":"object"},"line":{"properties":{"start":{"maximum":'
      + '360.0,"minimum":0.0,"description":"Start angle in SOCS [deg]","type":"'
      + 'number"},"program":{"$ref":"#/definitions/program"},"stop":{"maximum":'
      + '720.0,"minimum":0.0,"description":"Stop angle in SOCS [deg]","type":"n'
      + 'umber"},"increment":{"maximum":90.0,"minimum":0.0,"description":"Incre'
      + 'ment of angle in SOCS [deg]","type":"number"}},"description":"Line '
      + 'Scan Pattern","required":["start","stop","increment"],"type":"object"}'
      + ',"rectangular":{"properties":{"phi_stop":{"maximum":720.0,"minimum":0.'
      + '0,"description":"Stop phi angle in SOCS [deg]","type":"number"},"theta'
      + '_stop":{"maximum":180.0,"minimum":0.0,"description":"Stop theta angle '
      + 'in SOCS [deg]","type":"number"},"phi_start":{"maximum":360.0,"minimum"'
      + ':0.0,"description":"Start phi angle in SOCS [deg]","type":"number"},"p'
      + 'rogram":{"$ref":"#/definitions/program"},"phi_increment":{"maximum":90'
      + '.0,"minimum":0.0,"description":"Increment of phi angle in SOCS [deg]",'
      + '"type":"number"},"theta_increment":{"maximum":90.0,"minimum":0.0,"desc'
      + 'ription":"Increment of theta angle in SOCS [deg]","type":"number"},"th'
      + 'eta_start":{"maximum":180.0,"minimum":0.0,"description":"Start theta '
      + 'angle in SOCS [deg]","type":"number"}},"description":"Rectangular '
      + 'Field Of View Scan Pattern","required":["phi_start","phi_stop","phi_in'
      + 'crement","theta_start","theta_stop","theta_increment"],"type":"object"'
      + '}},"title":"Scan Pattern","description":"Scan pattern description","de'
      + 'finitions":{"program":{"properties":{"name":{"description":"Name of '
      + 'measurement program","type":"string"},"laser_prr":{"minimum":0,"exclus'
      + 'iveMinimum":false,"description":"Laser Pulse Repetition Rate '
      + '[Hz]","type":"number"}},"description":"Measurement '
      + 'program","required":["name"],"type":"object"}}}'
    );

    Example : (''
      + '{"rectangular":{"phi_stop":270.0,"theta_stop":130.0,"phi_start":45.0,"'
      + 'program":{"name":"High Speed","laser_prr":100000.0},"phi_increment":0.'
      + '04,"theta_increment":0.04,"theta_start":30.0}}'
    );
  );

// Details about laser shot files
const
  RDB_RIEGL_SHOT_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.shot_info';
    Title       : 'Shot Information';
    Description : 'Details about laser shot files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"sh'
      + 'ot_file":{"properties":{"file_uuid":{"description":"File''s Universally'
      + ' Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Shot file '
      + 'extension, without the leading dot","type":"string"}},"required":["fil'
      + 'e_extension"],"type":"object"}},"title":"Shot '
      + 'Information","description":"Details about laser shot '
      + 'files","type":"object"}'
    );

    Example : (''
      + '{"shot_file":{"file_uuid":"26a00815-67c0-4bff-8fe8-c577378fe663","file'
      + '_extension":"sodx"}}'
    );
  );

// Point filters applied in addition to the application-defined filters
const
  RDB_RIEGL_STORED_FILTERS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.stored_filters';
    Title       : 'Stored Filters';
    Description : 'Point filters applied in addition to the application-defined filters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"filters":{"description":"List of point '
      + 'filters","items":{"properties":{"title":{"description":"A short filter'
      + ' title (e.g. for display in a selection '
      + 'list)","type":"string"},"filter":{"description":"The RDB filter string'
      + ' to apply (e.g. when reading points or index), details see '
      + 'documentation of function '
      + 'select()","type":"string"},"description":{"description":"A brief '
      + 'description of the filter (e.g. for display in a '
      + 'tooltip)","type":"string"},"activated":{"description":"Apply (''true'') '
      + 'or ignore (''false'') this '
      + 'filter","type":"boolean"}},"description":"Point filter definition","re'
      + 'quired":["activated","title","description","filter"],"type":"object"},'
      + '"type":"array"},"activated":{"description":"Apply (''true'') or ignore '
      + '(''false'') all filters","type":"boolean"}},"title":"Stored '
      + 'filters","description":"Point filters applied in addition to the '
      + 'application-defined filters","required":["activated","filters"],"type"'
      + ':"object","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"filters":[{"title":"Ignore uncertain points from MTA '
      + 'resolution","filter":"riegl.mta_uncertain_point == '
      + '0","description":"Ignore points with uncertain MTA zone '
      + 'assignment","activated":false},{"title":"Ignore points below dynamic '
      + 'trigger level","filter":"riegl.dyntrig_uncertain_point == '
      + '0","description":"Ignore points with an echo signal amplitude below '
      + 'the dynamic trigger","activated":false},{"title":"Ignore points '
      + 'outside outer AABB","filter":"riegl.point_outside_aabb_bocs == '
      + '0","description":"Ignore points that are outside the outer AABB in '
      + 'BOCS","activated":false},{"title":"Ignore points inside inner '
      + 'AABB","filter":"riegl.point_inside_aabb_bocs == '
      + '0","description":"Ignore points that are inside the inner AABB in '
      + 'BOCS","activated":false}],"activated":true}'
    );
  );

// Details of major system components like lidar sensors, cameras and navigation devices
const
  RDB_RIEGL_SYSTEM_DESCRIPTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.system_description';
    Title       : 'System Description';
    Description : 'Details of major system components like lidar sensors, cameras and navigation devices';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"$class":{"enum":["Document"],"description":"Object '
      + 'class name","type":"string"},"author":{"description":"Name of the '
      + 'author that created the '
      + 'document","type":"string"},"timestamp":{"description":"Date and time '
      + 'of creation (e.g. 2019-06-19T13:32:10+02:00)","type":"string"},"versio'
      + 'n":{"description":"Document format '
      + 'version","type":"string"},"system":{"description":"The actual system '
      + 'description, details see documentation of RIEGL System '
      + 'Description","type":"object"}},"title":"System '
      + 'Description","description":"Details of major system components like '
      + 'lidar sensors, cameras and navigation devices","required":["$class","v'
      + 'ersion","author","timestamp","system"],"type":"object","$schema":"http'
      + '://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"$class":"Document","author":"RIEGL LMS GmbH, Austria","timestamp":"2'
      + '022-09-30T11:56:26+00:00","version":"1.2.1","system":{"details":"see '
      + 'documentation of RIEGL System Description"}}'
    );
  );

// Conversion of background radiation raw values to temperatures in °C
const
  RDB_RIEGL_TEMPERATURE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.temperature_calculation';
    Title       : 'Temperature Calculation Table';
    Description : 'Conversion of background radiation raw values to temperatures in °C';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"Si":{"$ref":"#/definitions/conversion_table","descript'
      + 'ion":"Conversion table for Si channel"},"InGaAs_Si_Difference":{"$ref"'
      + ':"#/definitions/conversion_table","description":"Conversion table for '
      + 'InGaAs - Si difference"},"InGaAs":{"$ref":"#/definitions/conversion_ta'
      + 'ble","description":"Conversion table for InGaAs '
      + 'channel"}},"title":"Temperature Calculation '
      + 'Table","description":"Conversion of background radiation raw values to'
      + ' temperatures in \u00b0C","type":"object","definitions":{"conversion_t'
      + 'able":{"properties":{"value":{"description":"LSB [1]","items":{"type":'
      + '"number"},"type":"array"},"temperature":{"description":"Temperature [\'
      + 'u00b0C]","items":{"type":"number"},"type":"array"}},"required":["value'
      + '","temperature"],"type":"object"}},"$schema":"http://json-schema.org/d'
      + 'raft-04/schema#"}'
    );

    Example : (''
      + '{"Si":{"value":[0.0,64.00097659230323,128.0019531846065,192.0029297769'
      + '097,256.0039063692129,320.00488296151616,384.0058595538194,448.0068361'
      + '461226,512.0078127384259],"temperature":[546.300048828125,548.81640512'
      + '12026,551.3143938500972,554.0144257850053,556.604252334815,559.2124464'
      + '488079,561.8022729986177,564.4104671126105,567.0002936624203]},"InGaAs'
      + '_Si_Difference":{"value":[1000.0,1100.090029602954,1200.04425183874,13'
      + '00.1342814416948,1400.0885036774805,1500.0427259132668,1600.1327555162'
      + '209,1700.0869777520065,1800.0411999877924],"temperature":[1749.9771111'
      + '17893,1749.977111117893,1749.977111117893,1749.977111117893,1749.97711'
      + '1117893,1749.977111117893,1744.7813348796044,1681.9971312601092,1622.3'
      + '944822534868]},"InGaAs":{"value":[0.0,64.00097659230323,128.0019531846'
      + '065,192.0029297769097,256.0039063692129,320.00488296151616,384.0058595'
      + '538194,448.0068361461226,512.0078127384259],"temperature":[307.2219672'
      + '2535614,309.1153478247277,311.1188086915047,313.10025350480055,315.213'
      + '7946389828,317.2172555057597,319.2207163725366,321.2021611858325,323.3'
      + '157023200148]}}'
    );
  );

// Base of timestamps (epoch)
const
  RDB_RIEGL_TIME_BASE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.time_base';
    Title       : 'Time Base';
    Description : 'Base of timestamps (epoch)';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"source":{"enum":["unknown","RTC","GNSS"],"description"'
      + ':"Timestamp source","type":"string"},"system":{"enum":["unknown","UTC"'
      + ',"GPS"],"description":"Time system (time '
      + 'standard)","type":"string"},"epoch":{"description":"Date and time of '
      + 'timestamp ''0'' as proposed by RFC 3339 (e.g. '
      + '2015-10-27T00:00:00+01:00).","type":"string"}},"title":"Time '
      + 'Base","description":"Base of timestamps (epoch)","required":["epoch","'
      + 'source"],"type":"object","$schema":"http://json-schema.org/draft-04/sc'
      + 'hema#"}'
    );

    Example : (''
      + '{"source":"GNSS","system":"UTC","epoch":"2015-10-27T00:00:00+00:00"}'
    );
  );

// Details about position+orientation files
const
  RDB_RIEGL_TRAJECTORY_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.trajectory_info';
    Title       : 'Trajectory Information';
    Description : 'Details about position+orientation files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"location":{"description":"Project location, e.g. city/'
      + 'state/country","type":"string"},"settings":{"description":"Settings '
      + 'used to calculate the trajectory (descriptive text)","type":"string"},'
      + '"field_of_application":{"enum":["unknown","SLS","TLS","KLS","MLS","ULS'
      + '","ALS","BLS","ILS"],"description":"Field of '
      + 'application","type":"string"},"company":{"description":"Company name",'
      + '"type":"string"},"navigation_frame":{"enum":["unknown","NED","ENU"],"d'
      + 'escription":"Navigation frame (NED: North-East-Down, ENU: '
      + 'East-North-Up)","type":"string"},"device":{"description":"Navigation '
      + 'device, e.g. '
      + 'name/type/serial","type":"string"},"software":{"description":"Software'
      + ' that calculated the trajectory (this may be the same or different '
      + 'software than the one that created the file)","type":"string"},"time_i'
      + 'nterval":{"properties":{"maximum":{"description":"Maximum time '
      + 'interval [s]","type":"number"},"average":{"description":"Average time '
      + 'interval [s]","type":"number"},"std_dev":{"description":"Standard '
      + 'deviation of intervals '
      + '[s]","type":"number"},"minimum":{"description":"Minimum time interval '
      + '[s]","type":"number"}},"description":"Time interval statistics","requi'
      + 'red":["minimum","average","maximum","std_dev"],"type":"object"},"proje'
      + 'ct":{"description":"Project '
      + 'name","type":"string"}},"title":"Trajectory '
      + 'Information","description":"Details about position+orientation files",'
      + '"required":["time_interval","navigation_frame"],"type":"object","$sche'
      + 'ma":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"location":"Horn","settings":"default","field_of_application":"MLS","'
      + 'company":"RIEGL LMS","navigation_frame":"NED","device":"IMU Model '
      + '12/1, Serial# 12345","software":"Navigation Software XYZ","time_interv'
      + 'al":{"maximum":0.005004883,"average":0.00500053,"std_dev":5.51e-07,"mi'
      + 'nimum":0.00500032},"project":"Campaign 3"}'
    );
  );

// Trigger-Timestamping-Unit/IP configuration
const
  RDB_RIEGL_TTIP_CONFIGURATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.ttip_configuration';
    Title       : 'TTIP Configuration';
    Description : 'Trigger-Timestamping-Unit/IP configuration';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"channel":{"minimum":0,"description":"ID of '
      + 'input/output channel","type":"integer"},"in_max_delay":{"minimum":0,"d'
      + 'escription":"maximum delay to output pulse before fake event is '
      + 'generated [0.1 msec], zero indicates that no fake events are generated'
      + '","type":"integer"},"out_polarity":{"minimum":0,"description":"0 .. '
      + 'positive edge, 1 .. negative '
      + 'edge","type":"integer"},"output_usage":{"minimum":0,"description":"0 '
      + '.. no output, 1 .. output derived from internal clock, 2 .. output '
      + 'derived from dmi, 3 .. output derived from external signal, 4 .. '
      + 'output static low, 5 .. output static high","type":"integer"},"out_num'
      + '_pulses":{"minimum":0,"description":"number of output pulses to be '
      + 'generated, 0 .. '
      + 'infinite","type":"integer"},"dmi_dist_per_tick":{"description":"dmi, '
      + 'distance per tick, just informative [m]","type":"number"},"out_duratio'
      + 'n":{"minimum":0,"description":"output pulse duration [0.1 msec]","type'
      + '":"integer"},"ext_bitmask":{"minimum":0,"description":"defines which '
      + 'of the internal pulse generators are to be started","type":"integer"},'
      + '"out_delay":{"minimum":0,"description":"output pulse initial delay '
      + 'after start [0.1 '
      + 'msec]","type":"integer"},"output_descr":{"description":"descriptive st'
      + 'ring","type":"string"},"num_channel":{"minimum":0,"description":"numbe'
      + 'r of input/output channels","type":"integer"},"dmi_max_time":{"minimum'
      + '":0,"description":"dmi, maximum time interval between trigger events '
      + '[0.1 msec]","type":"integer"},"dmi_min_time":{"minimum":0,"description'
      + '":"dmi, minimum time interval between trigger events [0.1 msec]","type'
      + '":"integer"},"in_min_duration":{"minimum":0,"description":"input '
      + 'signals with smaller pulse durations are ignored [0.1 '
      + 'msec]","type":"integer"},"dmi_incr":{"description":"dmi, increment in '
      + 'ticks","type":"integer"},"ext_signal":{"minimum":0,"description":"0 ..'
      + ' use input signal, 1 .. use output signal of channel","type":"integer"'
      + '},"in_max_duration":{"minimum":0,"description":"stops measurement of '
      + 'pulse duration of input signal [0.1 '
      + 'msec]","type":"integer"},"in_polarity":{"minimum":0,"description":"0 '
      + '.. positive edge, 1 .. negative edge","type":"integer"},"out_interval"'
      + ':{"minimum":0,"description":"output pulse interval [0.1 msec]","type":'
      + '"integer"},"ext_subdivider":{"minimum":0,"description":"reduces the '
      + 'frequency, default '
      + '1","type":"integer"},"input_descr":{"description":"descriptive '
      + 'string","type":"string"},"ext_channel":{"minimum":0,"description":"ID '
      + 'of channel used as external trigger input, 32 indicates none","type":"'
      + 'integer"},"ttip_version":{"minimum":0,"description":"following main.su'
      + 'b.ss.sss","type":"integer"},"input_usage":{"minimum":0,"description":"'
      + '0 .. deactivated, 1 .. just detecting and timestamping","type":"intege'
      + 'r"},"ext_delay":{"minimum":0,"description":"external trigger, time '
      + 'delay [0.1 msec]","type":"integer"}},"title":"TTIP '
      + 'Configuration","description":"Trigger-Timestamping-Unit/IP configurati'
      + 'on","required":["ttip_version","num_channel","ext_channel","ext_signal'
      + '","ext_delay","ext_subdivider","ext_bitmask","dmi_incr","dmi_min_time"'
      + ',"dmi_max_time","dmi_dist_per_tick","channel","output_descr","input_de'
      + 'scr","output_usage","input_usage","out_polarity","out_duration","out_i'
      + 'nterval","out_delay","out_num_pulses","in_polarity","in_min_duration",'
      + '"in_max_duration","in_max_delay"],"type":"object","$schema":"http://js'
      + 'on-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"channel":0,"in_max_delay":9990,"out_polarity":0,"output_usage":1,"ou'
      + 't_num_pulses":1,"dmi_dist_per_tick":0.0,"out_duration":300,"ext_bitmas'
      + 'k":0,"out_delay":0,"output_descr":"Port 1 - Trigger","num_channel":9,"'
      + 'dmi_max_time":0,"dmi_min_time":0,"in_min_duration":0,"dmi_incr":0,"ext'
      + '_signal":0,"in_max_duration":10000,"in_polarity":0,"out_interval":1000'
      + '0,"ext_subdivider":1,"input_descr":"Port 1 - Exposure","ext_channel":3'
      + '2,"ttip_version":1,"input_usage":1,"ext_delay":0}'
    );
  );

// Details about vertex file
const
  RDB_RIEGL_VERTEX_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.vertex_info';
    Title       : 'Vertex Information';
    Description : 'Details about vertex file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","properties":{"ve'
      + 'rtex_file":{"properties":{"file_uuid":{"description":"File''s '
      + 'Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Vertex file '
      + 'extension, without the leading dot","type":"string"}},"required":["fil'
      + 'e_extension"],"type":"object"}},"title":"Vertex '
      + 'Information","description":"Details about vertex '
      + 'file","type":"object"}'
    );

    Example : (''
      + '{"vertex_file":{"file_uuid":"51534d95-d71f-4f36-ae1a-3e63a21fd1c7","fi'
      + 'le_extension":"vtx"}}'
    );
  );

// Details about the voxels contained in the file
const
  RDB_RIEGL_VOXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.voxel_info';
    Title       : 'Voxel Information';
    Description : 'Details about the voxels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"title":"Voxel Information","description":"Details about the voxels '
      + 'contained in the file","type":"object","definitions":{"shape_threshold'
      + 's":{"properties":{"line":{"minimum":1,"exclusiveMinimum":true,"descrip'
      + 'tion":"If the biggest eigenvalue is bigger than the median eigenvalue '
      + '* line_threshold, the voxel is considered a line.","type":"number"},"p'
      + 'lane":{"maximum":1,"exclusiveMaximum":true,"exclusiveMinimum":true,"de'
      + 'scription":"If the smallest eigenvalue is smaller than the median '
      + 'eigenvalue * plane_threshold, the voxel is considered a '
      + 'plane.","type":"number","minimum":0}},"description":"Thresholds used '
      + 'to compute the voxel''s shape_id value.","required":["plane","line"],"t'
      + 'ype":"object"},"voxel_size":{"maxItems":3,"minItems":3,"description":"'
      + 'Size of voxels.","type":"array","items":{"$ref":"#/definitions/edge_le'
      + 'ngth"}},"voxel_size_cubic":{"$ref":"#/definitions/edge_length","type":'
      + '"number"},"voxel_origin_point":{"maxItems":3,"minItems":3,"description'
      + '":"Origin point for all voxel indices in voxel CRS.","type":"array","i'
      + 'tems":{"type":"number"}},"voxel_type":{"default":"centroid","enum":["c'
      + 'enter","centroid","index"],"description":"Whether a point in a voxel '
      + 'represents its center or its centroid. If type is <tt>index</tt> there'
      + ' is no point but only an integer voxel index."},"voxel_origin_enum":{"'
      + 'default":"corner","enum":["center","corner"],"description":"Defines '
      + 'whether the voxel''s center or a corner is placed on CRS origin <tt>(0/'
      + '0/0)</tt>."},"edge_length":{"minimum":0,"exclusiveMinimum":true,"descr'
      + 'iption":"Length of voxel edge [m].","type":"number"}},"$schema":"http:'
      + '//json-schema.org/draft-04/schema#","oneOf":[{"properties":{"shape_thr'
      + 'esholds":{"$ref":"#/definitions/shape_thresholds"},"voxel_type":{"$ref'
      + '":"#/definitions/voxel_type"},"voxel_origin":{"$ref":"#/definitions/vo'
      + 'xel_origin_enum"},"size":{"description":"Size of voxels in file '
      + 'coordinate system.","oneOf":[{"$ref":"#/definitions/voxel_size"},{"$re'
      + 'f":"#/definitions/voxel_size_cubic"}]}},"additionalProperties":false,"'
      + 'required":["size","voxel_origin","voxel_type"]},{"properties":{"shape_'
      + 'thresholds":{"$ref":"#/definitions/shape_thresholds"},"reference_point'
      + '":{"maxItems":2,"minItems":2,"description":"Point in WGS84 geodetic '
      + 'decimal degree (EPSG:4326) that was used to compute the projection '
      + 'distortion parameters. The coefficient order is latitude, longitude. '
      + 'Only voxels with corresponding geo_tag, voxel_size and reference_point'
      + ' can be reliably processed together. This entry is available for voxel'
      + ' files in projected CRS only.","type":"array","items":{"maximum":180,"'
      + 'minimum":-180,"type":"number"}},"size":{"$ref":"#/definitions/voxel_si'
      + 'ze","description":"Size of voxels in file coordinate system."},"voxel_'
      + 'origin":{"oneOf":[{"$ref":"#/definitions/voxel_origin_enum"},{"$ref":"'
      + '#/definitions/voxel_origin_point","description":"The base point of the'
      + ' voxel grid. Used together with <tt>voxel_size</tt> and '
      + '<tt>voxel_index</tt> to compute actual point coordinates."}]},"voxel_t'
      + 'ype":{"$ref":"#/definitions/voxel_type"},"size_llcs":{"$ref":"#/defini'
      + 'tions/voxel_size","description":"Size of voxels in a locally levelled '
      + 'cartesian coordinate system (xyz). This is only used for voxels based '
      + 'on a map projection."}},"additionalProperties":false,"required":["refe'
      + 'rence_point","size_llcs","size","voxel_origin","voxel_type"]}]}'
    );

    Example : (''
      + '{"shape_thresholds":{"line":6,"plane":0.16},"reference_point":[48,16],'
      + '"size":[0.5971642834779395,0.5971642834779395,0.5143705304787237],"vox'
      + 'el_origin":"corner","voxel_type":"centroid","size_llcs":[0.51565752528'
      + '91171,0.5130835356683303,0.5143705304787237]}'
    );
  );

// Settings for waveform averaging
const
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_averaging_settings';
    Title       : 'Waveform Averaging Settings';
    Description : 'Settings for waveform averaging';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"num_shots":{"minimum":1,"description":"Number of '
      + 'consecutive shots to be used for averaging.","type":"integer"},"mta_zo'
      + 'ne":{"minimum":1,"description":"Fixed MTA zone for averaging.","type":'
      + '"integer"},"trim":{"maximum":0.5,"minimum":0,"default":0,"description"'
      + ':"Percentage for robust '
      + 'averaging.","type":"number"}},"title":"Waveform Averaging '
      + 'Settings","description":"Settings for waveform averaging","required":['
      + '"num_shots","mta_zone"],"type":"object","$schema":"http://json-schema.'
      + 'org/draft-04/schema#"}'
    );

    Example : (''
      + '{"num_shots":7,"mta_zone":1,"trim":0.05}'
    );
  );

// Details about waveform files
const
  RDB_RIEGL_WAVEFORM_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_info';
    Title       : 'Waveform Information';
    Description : 'Details about waveform files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"sample_data_files":{"items":{"properties":{"file_uuid"'
      + ':{"description":"File''s Universally Unique Identifier (RFC 4122)","typ'
      + 'e":"string"},"channel":{"maximum":255,"exclusiveMaximum":false,"exclus'
      + 'iveMinimum":false,"description":"Sample block channel number (255 = in'
      + 'valid)","type":"integer","minimum":0},"delta_st":{"description":"reser'
      + 'ved","type":"number"},"sample_interval":{"minimum":0,"exclusiveMinimum'
      + '":false,"description":"Sampling interval in '
      + 'seconds","type":"number"},"channel_name":{"description":"Sample block '
      + 'channel name","type":"string"},"laser_wavelength":{"minimum":0,"exclus'
      + 'iveMinimum":false,"description":"Laser wavelength in meters (0 = '
      + 'unknown)","type":"number"},"file_extension":{"description":"Sample '
      + 'data file extension, without the leading dot","type":"string"},"sample'
      + '_bits":{"maximum":32,"exclusiveMaximum":false,"exclusiveMinimum":false'
      + ',"description":"Bitwidth of samples (e.g. 10 bit, 12 bit)","type":"int'
      + 'eger","minimum":0}},"required":["channel","channel_name","sample_inter'
      + 'val","sample_bits","laser_wavelength","delta_st","file_extension"],"ty'
      + 'pe":"object"},"type":"array"},"sample_block_file":{"properties":{"file'
      + '_uuid":{"description":"File''s Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Sample block '
      + 'file extension, without the leading dot","type":"string"}},"required":'
      + '["file_extension"],"type":"object"},"range_offset_m":{"description":"C'
      + 'alibrated device specific range offset for waveform analysis by system'
      + ' response fitting in meters.","type":"number"},"range_offset_waveform_'
      + 'samples_m":{"description":"Calibrated device specific range offset for'
      + ' waveform samples in meters.","type":"number"}},"title":"Waveform '
      + 'Information","description":"Details about waveform files","required":['
      + '"sample_block_file","sample_data_files"],"type":"object","$schema":"ht'
      + 'tp://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"sample_data_files":[{"file_uuid":"da084413-e3e8-4655-a122-071de8490d'
      + '8e","channel":0,"delta_st":0,"channel_name":"high_power","sample_inter'
      + 'val":1.00503e-09,"laser_wavelength":0,"file_extension":"sp0","sample_b'
      + 'its":12},{"file_uuid":"93585b5e-5ea9-43a1-947b-e7ba3be642d2","channel"'
      + ':1,"delta_st":0,"channel_name":"low_power","sample_interval":1.00503e-'
      + '09,"laser_wavelength":0,"file_extension":"sp1","sample_bits":12},{"fil'
      + 'e_uuid":"9d2298c4-1036-464f-b5cb-1cf8e517f3a0","channel":5,"delta_st":'
      + '0,"channel_name":"wwf","sample_interval":1.00503e-09,"laser_wavelength'
      + '":0,"file_extension":"sp5","sample_bits":12}],"sample_block_file":{"fi'
      + 'le_uuid":"93a03615-66c0-4bea-8ff8-c577378fe660","file_extension":"sbx"'
      + '},"range_offset_waveform_samples_m ":7.283,"range_offset_m":3.1415}'
    );
  );

// Scanner settings for waveform output
const
  RDB_RIEGL_WAVEFORM_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_settings';
    Title       : 'Waveform Settings';
    Description : 'Scanner settings for waveform output';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","title":"Waveform'
      + ' Settings","description":"Scanner settings for waveform output","items'
      + '":{"properties":{"pass_rng_greater":{"description":"Threshold for '
      + 'range greater than '
      + '[m]","type":"number"},"logic_expression":{"description":"Logic '
      + 'expression of smart waveforms '
      + 'filter","type":"string"},"pass_rng_less":{"description":"Threshold for'
      + ' range less than '
      + '[m]","type":"number"},"pass_ampl_greater":{"description":"Threshold '
      + 'for amplitude greater than '
      + '[dB]","type":"number"},"pass_ampl_less":{"description":"Threshold for '
      + 'amplitude less than '
      + '[dB]","type":"number"},"channel_idx_mask":{"description":"Bit mask for'
      + ' channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = '
      + 'Bit1, ...","type":"integer"},"pass_dev_less":{"description":"Threshold'
      + ' for deviation less than '
      + '[1]","type":"integer"},"sbl_name":{"description":"Name of sample '
      + 'block, e.g.: wfm, '
      + 'wwf","type":"string"},"smart_enabled":{"description":"Smart waveform '
      + 'output enabled","type":"boolean"},"pass_dev_greater":{"description":"T'
      + 'hreshold for deviation greater than '
      + '[1]","type":"integer"},"enabled":{"description":"Waveform output enabl'
      + 'ed","type":"boolean"}},"required":["sbl_name","enabled","channel_idx_m'
      + 'ask"],"type":"object"},"type":"array"}'
    );

    Example : (''
      + '[{"pass_rng_greater":9.27,"pass_rng_less":13.11,"pass_ampl_greater":1.'
      + '0,"pass_ampl_less":5.0,"channel_idx_mask":11,"sbl_name":"wfm","smart_e'
      + 'nabled":true,"enabled":true},{"channel_idx_mask":32,"sbl_name":"wwf","'
      + 'enabled":false}]'
    );
  );

// Window analysis data estimated from scandata and resulting filter parameters
const
  RDB_RIEGL_WINDOW_ANALYSIS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_analysis';
    Title       : 'Window Analysis';
    Description : 'Window analysis data estimated from scandata and resulting filter parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"settings":{"properties":{"amplitude":{"properties":{"a'
      + 'dditive_value":{"type":"number"},"sigma_factor":{"type":"number"}},"re'
      + 'quired":["sigma_factor","additive_value"],"type":"object"},"range":{"p'
      + 'roperties":{"additive_value":{"type":"number"},"sigma_factor":{"type":'
      + '"number"}},"required":["sigma_factor","additive_value"],"type":"object'
      + '"}},"required":["range","amplitude"],"type":"object"},"result":{"prope'
      + 'rties":{"angle":{"description":"[deg]","items":{"type":"number"},"type'
      + '":"array"},"amplitude_offset":{"description":"[dB]","items":{"type":"n'
      + 'umber"},"type":"array"},"timestamp":{"description":"[s]","items":{"typ'
      + 'e":"number"},"type":"array"},"range_sigma":{"description":"[m]","items'
      + '":{"type":"number"},"type":"array"},"range_mean":{"description":"[m]",'
      + '"items":{"type":"number"},"type":"array"},"amplitude_mean":{"descripti'
      + 'on":"[dB]","items":{"type":"number"},"type":"array"},"amplitude_sigma"'
      + ':{"description":"[dB]","items":{"type":"number"},"type":"array"}},"req'
      + 'uired":["angle","range_mean","range_sigma","amplitude_mean","amplitude'
      + '_sigma","amplitude_offset"],"type":"object"},"filter":{"properties":{"'
      + 'angle":{"description":"[deg]","items":{"type":"number"},"type":"array"'
      + '},"range_min":{"description":"[m]","items":{"type":"number"},"type":"a'
      + 'rray"},"range_max":{"description":"[m]","items":{"type":"number"},"typ'
      + 'e":"array"},"amplitude_max":{"description":"[dB]","items":{"type":"num'
      + 'ber"},"type":"array"}},"required":["angle","range_min","range_max","am'
      + 'plitude_max"],"type":"object"}},"title":"Window '
      + 'Analysis","description":"Window analysis data estimated from scandata '
      + 'and resulting filter parameters","required":["result","filter","settin'
      + 'gs"],"type":"object","$schema":"http://json-schema.org/draft-04/schema'
      + '#"}'
    );

    Example : (''
      + '{"settings":{"amplitude":{"additive_value":1.0,"sigma_factor":4},"rang'
      + 'e":{"additive_value":0.1,"sigma_factor":8}},"result":{"angle":[14.9,15'
      + '.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],"amplitude_offset":[1'
      + '.9,1.9],"timestamp":[408.4441,411.4443],"range_sigma":[0.01869652,0.02'
      + '151435,0.01747969,0.01918765,0.01945776,0.01934862,0.01955329,0.022255'
      + '89,0.02229977,0.01899122,0.02009433],"range_mean":[0.1105621,0.1079564'
      + ',0.1087088,0.1067261,0.1054582,0.1090412,0.102871,0.1019044,0.1051523,'
      + '0.1058445,0.1031261],"amplitude_mean":[5.347396,5.263155,5.224655,5.17'
      + '9926,5.097782,5.116479,5.051756,4.983473,5.007885,5.002441,4.982],"amp'
      + 'litude_sigma":[0.4272844,0.4298479,0.4236816,0.4283583,0.4362353,0.431'
      + '5141,0.4373984,0.4472798,0.4346001,0.4345487,0.4540681]},"filter":{"an'
      + 'gle":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,15.9],"range_m'
      + 'in":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,-0.219,-0.221,-0.223,-0.'
      + '225,-0.227],"range_max":[0.424,0.425,0.426,0.427,0.428,0.428,0.429,0.4'
      + '3,0.431,0.431,0.432],"amplitude_max":[8.04,8.01,7.99,7.96,7.93,7.9,7.8'
      + '8,7.85,7.83,7.8,7.78]}}'
    );
  );

// Correction parameters for window glass echoes
const
  RDB_RIEGL_WINDOW_ECHO_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_echo_correction';
    Title       : 'Window Echo Correction';
    Description : 'Correction parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"slices":{"items":{"properties":{"table":{"minItems":1,'
      + '"description":"Correction table (dimension defined by the ''amplitude'' '
      + 'and ''range'' objects)","items":{"minItems":1,"description":"Table row '
      + '(= amplitude '
      + 'axis)","items":{"maxItems":3,"minItems":3,"description":"Table column '
      + '(= range axis)","items":{"description":"Table cell (item 0: amplitude '
      + 'in dB, 1: range in m, 2: flags)","type":"number"},"type":"array"},"typ'
      + 'e":"array"},"type":"array"},"amplitude":{"description":"Window echo '
      + 'amplitude of slice in dB","type":"number"}},"description":"Window echo'
      + ' correction parameter slice","required":["amplitude","table"],"type":"'
      + 'object"},"type":"array"},"amplitude":{"properties":{"maximum":{"minimu'
      + 'm":0.0,"description":"Maximum amplitude in '
      + 'dB","type":"number"},"minimum":{"minimum":0.0,"description":"Minimum '
      + 'amplitude in '
      + 'dB","type":"number"},"entries":{"minimum":1,"description":"Number of '
      + 'amplitude entries","type":"integer"}},"description":"Amplitude axis of'
      + ' correction table","required":["minimum","maximum","entries"],"type":"'
      + 'object"},"range":{"properties":{"maximum":{"maximum":2.0,"minimum":-2.'
      + '0,"description":"Maximum range in m","type":"number"},"minimum":{"maxi'
      + 'mum":2.0,"minimum":-2.0,"description":"Minimum range in '
      + 'm","type":"number"},"entries":{"minimum":1,"description":"Number of '
      + 'range entries","type":"integer"}},"description":"Range axis of '
      + 'correction table","required":["minimum","maximum","entries"],"type":"o'
      + 'bject"}},"title":"Window Echo Correction","description":"Correction '
      + 'parameters for window glass echoes","required":["amplitude","range","s'
      + 'lices"],"type":"object","$schema":"http://json-schema.org/draft-04/sch'
      + 'ema#"}'
    );

    Example : (''
      + '{"slices":[{"table":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],"amplitude"'
      + ':1.5},{"table":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],"amplitude":2.0}'
      + '],"amplitude":{"maximum":20,"minimum":2,"entries":128},"range":{"maxim'
      + 'um":1.5060822940732335,"minimum":-1.5060822940732335,"entries":128}}'
    );
  );

// Table of all meta data item details records
const
  RDB_META_DATA_ITEMS : array of PRDBPointcloudMetaDataItemInfo = nil; // filled during initialization

implementation

procedure FixStringEncoding;
begin
  // As the unit (.pas file) doesn't contain a BOM, we need to convert all strings
  // from UTF-8 to "native" encoding at runtime (tested on Delphi 7 and Delphi XE5)

  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example)));

  RDB_RIEGL_ATMOSPHERE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Name)));
  RDB_RIEGL_ATMOSPHERE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Title)));
  RDB_RIEGL_ATMOSPHERE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Description)));
  RDB_RIEGL_ATMOSPHERE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Schema)));
  RDB_RIEGL_ATMOSPHERE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Example)));

  RDB_RIEGL_BEAM_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Name)));
  RDB_RIEGL_BEAM_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Title)));
  RDB_RIEGL_BEAM_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Description)));
  RDB_RIEGL_BEAM_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Schema)));
  RDB_RIEGL_BEAM_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Example)));

  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example)));

  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example)));

  RDB_RIEGL_DETECTION_PROBABILITY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Name)));
  RDB_RIEGL_DETECTION_PROBABILITY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Title)));
  RDB_RIEGL_DETECTION_PROBABILITY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Description)));
  RDB_RIEGL_DETECTION_PROBABILITY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Schema)));
  RDB_RIEGL_DETECTION_PROBABILITY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Example)));

  RDB_RIEGL_DEVICE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Name)));
  RDB_RIEGL_DEVICE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Title)));
  RDB_RIEGL_DEVICE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Description)));
  RDB_RIEGL_DEVICE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Schema)));
  RDB_RIEGL_DEVICE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example)));

  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example)));

  RDB_RIEGL_DEVICES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Name)));
  RDB_RIEGL_DEVICES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Title)));
  RDB_RIEGL_DEVICES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Description)));
  RDB_RIEGL_DEVICES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Schema)));
  RDB_RIEGL_DEVICES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Example)));

  RDB_RIEGL_DYNTRIG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Name)));
  RDB_RIEGL_DYNTRIG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Title)));
  RDB_RIEGL_DYNTRIG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Description)));
  RDB_RIEGL_DYNTRIG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Schema)));
  RDB_RIEGL_DYNTRIG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DYNTRIG.Example)));

  RDB_RIEGL_ECHO_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Name)));
  RDB_RIEGL_ECHO_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Title)));
  RDB_RIEGL_ECHO_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Description)));
  RDB_RIEGL_ECHO_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Schema)));
  RDB_RIEGL_ECHO_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Example)));

  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example)));

  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example)));

  RDB_RIEGL_GEO_TAG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Name)));
  RDB_RIEGL_GEO_TAG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Title)));
  RDB_RIEGL_GEO_TAG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Description)));
  RDB_RIEGL_GEO_TAG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Schema)));
  RDB_RIEGL_GEO_TAG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Example)));

  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example)));

  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example)));

  RDB_RIEGL_ITEM_NAMES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Name)));
  RDB_RIEGL_ITEM_NAMES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Title)));
  RDB_RIEGL_ITEM_NAMES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Description)));
  RDB_RIEGL_ITEM_NAMES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Schema)));
  RDB_RIEGL_ITEM_NAMES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Example)));

  RDB_RIEGL_LICENSES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Name)));
  RDB_RIEGL_LICENSES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Title)));
  RDB_RIEGL_LICENSES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Description)));
  RDB_RIEGL_LICENSES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Schema)));
  RDB_RIEGL_LICENSES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Example)));

  RDB_RIEGL_MTA_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Name)));
  RDB_RIEGL_MTA_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Title)));
  RDB_RIEGL_MTA_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Description)));
  RDB_RIEGL_MTA_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Schema)));
  RDB_RIEGL_MTA_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Example)));

  RDB_RIEGL_NEAR_RANGE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Name)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Title)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Description)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Example)));

  RDB_RIEGL_NOISE_ESTIMATES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Name)));
  RDB_RIEGL_NOISE_ESTIMATES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Title)));
  RDB_RIEGL_NOISE_ESTIMATES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Description)));
  RDB_RIEGL_NOISE_ESTIMATES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Schema)));
  RDB_RIEGL_NOISE_ESTIMATES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Example)));

  RDB_RIEGL_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Name)));
  RDB_RIEGL_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Title)));
  RDB_RIEGL_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Description)));
  RDB_RIEGL_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Schema)));
  RDB_RIEGL_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Example)));

  RDB_RIEGL_PIXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Name)));
  RDB_RIEGL_PIXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Title)));
  RDB_RIEGL_PIXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Description)));
  RDB_RIEGL_PIXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Schema)));
  RDB_RIEGL_PIXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Example)));

  RDB_RIEGL_PLANE_PATCH_MATCHING.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Name)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Title)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Description)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Schema)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Example)));

  RDB_RIEGL_PLANE_PATCH_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Name)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Title)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Description)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Example)));

  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example)));

  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example)));

  RDB_RIEGL_POINTCLOUD_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Name)));
  RDB_RIEGL_POINTCLOUD_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Title)));
  RDB_RIEGL_POINTCLOUD_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Description)));
  RDB_RIEGL_POINTCLOUD_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Schema)));
  RDB_RIEGL_POINTCLOUD_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Example)));

  RDB_RIEGL_POSE_ESTIMATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Name)));
  RDB_RIEGL_POSE_ESTIMATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Title)));
  RDB_RIEGL_POSE_ESTIMATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Description)));
  RDB_RIEGL_POSE_ESTIMATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Schema)));
  RDB_RIEGL_POSE_ESTIMATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Example)));

  RDB_RIEGL_POSE_SENSORS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Name)));
  RDB_RIEGL_POSE_SENSORS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Title)));
  RDB_RIEGL_POSE_SENSORS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Description)));
  RDB_RIEGL_POSE_SENSORS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Schema)));
  RDB_RIEGL_POSE_SENSORS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Example)));

  RDB_RIEGL_PULSE_POSITION_MODULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Name)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Title)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Description)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Schema)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Example)));

  RDB_RIEGL_RANGE_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Name)));
  RDB_RIEGL_RANGE_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Title)));
  RDB_RIEGL_RANGE_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Description)));
  RDB_RIEGL_RANGE_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Schema)));
  RDB_RIEGL_RANGE_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Example)));

  RDB_RIEGL_RECEIVER_INTERNALS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Name)));
  RDB_RIEGL_RECEIVER_INTERNALS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Title)));
  RDB_RIEGL_RECEIVER_INTERNALS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Description)));
  RDB_RIEGL_RECEIVER_INTERNALS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Schema)));
  RDB_RIEGL_RECEIVER_INTERNALS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Example)));

  RDB_RIEGL_REFLECTANCE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Name)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Title)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Description)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Schema)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Example)));

  RDB_RIEGL_REFLECTANCE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Name)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Title)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Description)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Schema)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Example)));

  RDB_RIEGL_SCAN_PATTERN.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Name)));
  RDB_RIEGL_SCAN_PATTERN.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Title)));
  RDB_RIEGL_SCAN_PATTERN.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Description)));
  RDB_RIEGL_SCAN_PATTERN.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Schema)));
  RDB_RIEGL_SCAN_PATTERN.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Example)));

  RDB_RIEGL_SHOT_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Name)));
  RDB_RIEGL_SHOT_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Title)));
  RDB_RIEGL_SHOT_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Description)));
  RDB_RIEGL_SHOT_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Schema)));
  RDB_RIEGL_SHOT_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Example)));

  RDB_RIEGL_STORED_FILTERS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Name)));
  RDB_RIEGL_STORED_FILTERS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Title)));
  RDB_RIEGL_STORED_FILTERS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Description)));
  RDB_RIEGL_STORED_FILTERS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Schema)));
  RDB_RIEGL_STORED_FILTERS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Example)));

  RDB_RIEGL_SYSTEM_DESCRIPTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Name)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Title)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Description)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Schema)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Example)));

  RDB_RIEGL_TEMPERATURE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Name)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Title)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Description)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Schema)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Example)));

  RDB_RIEGL_TIME_BASE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Name)));
  RDB_RIEGL_TIME_BASE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Title)));
  RDB_RIEGL_TIME_BASE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Description)));
  RDB_RIEGL_TIME_BASE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Schema)));
  RDB_RIEGL_TIME_BASE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Example)));

  RDB_RIEGL_TRAJECTORY_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Name)));
  RDB_RIEGL_TRAJECTORY_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Title)));
  RDB_RIEGL_TRAJECTORY_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Description)));
  RDB_RIEGL_TRAJECTORY_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Schema)));
  RDB_RIEGL_TRAJECTORY_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Example)));

  RDB_RIEGL_TTIP_CONFIGURATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Name)));
  RDB_RIEGL_TTIP_CONFIGURATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Title)));
  RDB_RIEGL_TTIP_CONFIGURATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Description)));
  RDB_RIEGL_TTIP_CONFIGURATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Schema)));
  RDB_RIEGL_TTIP_CONFIGURATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Example)));

  RDB_RIEGL_VERTEX_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Name)));
  RDB_RIEGL_VERTEX_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Title)));
  RDB_RIEGL_VERTEX_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Description)));
  RDB_RIEGL_VERTEX_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Schema)));
  RDB_RIEGL_VERTEX_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Example)));

  RDB_RIEGL_VOXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Name)));
  RDB_RIEGL_VOXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Title)));
  RDB_RIEGL_VOXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Description)));
  RDB_RIEGL_VOXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Schema)));
  RDB_RIEGL_VOXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Example)));

  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example)));

  RDB_RIEGL_WAVEFORM_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Name)));
  RDB_RIEGL_WAVEFORM_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Title)));
  RDB_RIEGL_WAVEFORM_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Description)));
  RDB_RIEGL_WAVEFORM_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Schema)));
  RDB_RIEGL_WAVEFORM_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Example)));

  RDB_RIEGL_WAVEFORM_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Example)));

  RDB_RIEGL_WINDOW_ANALYSIS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Name)));
  RDB_RIEGL_WINDOW_ANALYSIS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Title)));
  RDB_RIEGL_WINDOW_ANALYSIS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Description)));
  RDB_RIEGL_WINDOW_ANALYSIS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Schema)));
  RDB_RIEGL_WINDOW_ANALYSIS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Example)));

  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example)));
end;

procedure FillMetadataArray;
var
  i : Integer;
begin
  SetLength(RDB_META_DATA_ITEMS, 52); i := -1;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ANGULAR_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ATMOSPHERE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_BEAM_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_CATALOG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DETECTION_PROBABILITY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_OUTPUT_LIMITS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DYNTRIG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ECHO_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_EXPONENTIAL_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GAUSSIAN_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEO_TAG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOMETRIC_SCALE_FACTOR;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOREFERENCING_PARAMETERS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ITEM_NAMES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_LICENSES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_MTA_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NEAR_RANGE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOISE_ESTIMATES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PIXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_MATCHING;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_SLOPE_CLASS_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINT_ATTRIBUTE_GROUPS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINTCLOUD_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_ESTIMATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_SENSORS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PULSE_POSITION_MODULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RANGE_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RECEIVER_INTERNALS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SCAN_PATTERN;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SHOT_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_STORED_FILTERS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SYSTEM_DESCRIPTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TEMPERATURE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TIME_BASE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TRAJECTORY_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TTIP_CONFIGURATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VERTEX_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VOXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ANALYSIS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ECHO_CORRECTION;
end;

initialization

FixStringEncoding;
FillMetadataArray;

end.
